@@ -2,9 +2,7 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#ifndef S_SPLINT_S
 #include <unistd.h>
-#endif /* S_SPLINT_S */
 
 #include "gpsd_config.h"
 #ifndef HAVE_DAEMON
@@ -21,7 +19,6 @@ int daemon(int nochdir, int noclose)
 {
     int fd;
 
-    /*@ -type @*//* weirdly, splint 3.1.2 is confused by fork() */
     switch (fork()) {
     case -1:
 	return -1;
@@ -30,13 +27,11 @@ int daemon(int nochdir, int noclose)
     default:			/* parent side */
 	exit(EXIT_SUCCESS);
     }
-    /*@ +type @*/
 
     if (setsid() == -1)
 	return -1;
     if ((nochdir==0) && (chdir("/") == -1))
 	return -1;
-    /*@ -nullpass @*/
     if ((noclose==0) && (fd = open(_PATH_DEVNULL, O_RDWR, 0)) != -1) {
 	(void)dup2(fd, STDIN_FILENO);
 	(void)dup2(fd, STDOUT_FILENO);
@@ -44,7 +39,6 @@ int daemon(int nochdir, int noclose)
 	if (fd > 2)
 	    (void)close(fd);
     }
-    /*@ +nullpass @*/
     /* coverity[leaked_handle] Intentional handle duplication */
     return 0;
 }
