@@ -29,14 +29,8 @@
 static void from_sixbit(unsigned char *bitvec, uint start, int count, char *to)
 /* beginning at bitvec bit start, unpack count sixbit characters */
 {
-    /*@ +type @*/
-#ifdef S_SPLINT_S
-    /* the real string causes a splint internal error */
-    const char sixchr[] = "abcd";
-#else
     const char sixchr[64] =
 	"@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_ !\"#$%&'()*+,-./0123456789:;<=>?";
-#endif /* S_SPLINT_S */
     int i;
 
     /* six-bit to ASCII */
@@ -55,10 +49,8 @@ static void from_sixbit(unsigned char *bitvec, uint start, int count, char *to)
 	    to[i] = '\0';
 	else
 	    break;
-    /*@ -type @*/
 }
 
-/*@ +charint @*/
 bool ais_binary_decode(const struct gpsd_errout_t *errout,
 		       struct ais_t *ais,
 		       const unsigned char *bits, size_t bitlen,
@@ -67,9 +59,6 @@ bool ais_binary_decode(const struct gpsd_errout_t *errout,
 {
     unsigned int u; int i;
 
-#ifdef S_SPLINT_S
-    assert(type24_queue != NULL);
-#endif /* S_SPLINT_S */
 #define UBITS(s, l)	ubits((unsigned char *)bits, s, l, false)
 #define SBITS(s, l)	sbits((signed char *)bits, s, l, false)
 #define UCHARS(s, to)	from_sixbit((unsigned char *)bits, s, sizeof(to)-1, to)
@@ -183,7 +172,7 @@ bool ais_binary_decode(const struct gpsd_errout_t *errout,
 	ais->type6.dac            = UBITS(72, 10);
 	ais->type6.fid            = UBITS(82, 6);
 	ais->type6.bitcount       = bitlen - 88;
-	/* not strictly required - helps stability in testing */ 
+	/* not strictly required - helps stability in testing */
 	(void)memset(ais->type6.bitdata, '\0', sizeof(ais->type6.bitdata));
 	ais->type6.structured = false;
 	/* Inland AIS */
@@ -433,18 +422,16 @@ bool ais_binary_decode(const struct gpsd_errout_t *errout,
     case 13: /* Safety Related Acknowledge */
     {
 	unsigned int mmsi[4];
-	RANGE_CHECK(72, 158);
+	RANGE_CHECK(72, 168);
 	for (u = 0; u < sizeof(mmsi)/sizeof(mmsi[0]); u++)
 	    if (bitlen > 40 + 32*u)
 		mmsi[u] = UBITS(40 + 32*u, 30);
 	    else
 		mmsi[u] = 0;
-	/*@ -usedef @*/
 	ais->type7.mmsi1 = mmsi[0];
 	ais->type7.mmsi2 = mmsi[1];
 	ais->type7.mmsi3 = mmsi[2];
 	ais->type7.mmsi4 = mmsi[3];
-	/*@ +usedef @*/
 	break;
     }
     case 8: /* Binary Broadcast Message */
@@ -453,7 +440,7 @@ bool ais_binary_decode(const struct gpsd_errout_t *errout,
 	ais->type8.dac            = UBITS(40, 10);
 	ais->type8.fid            = UBITS(50, 6);
 	ais->type8.bitcount       = bitlen - 56;
-	/* not strictly required - helps stability in testing */ 
+	/* not strictly required - helps stability in testing */
 	(void)memset(ais->type8.bitdata, '\0', sizeof(ais->type8.bitdata));
 	ais->type8.structured = false;
 	if (ais->type8.dac == 1)
@@ -666,7 +653,7 @@ bool ais_binary_decode(const struct gpsd_errout_t *errout,
 		ais->type8.dac200fid10.heading_q	= (bool)UBITS(159, 1);
 		/* skip 8 bits */
 		/*
-		 * Attempt to prevent false matches with this message type 
+		 * Attempt to prevent false matches with this message type
 		 * by range-checking certain fields.
 		 */
 		if (ais->type8.dac200fid10.hazard > DAC200FID10_HAZARD_MAX
@@ -809,9 +796,9 @@ bool ais_binary_decode(const struct gpsd_errout_t *errout,
     case 17:	/* GNSS Broadcast Binary Message */
 	RANGE_CHECK(80, 816);
 	//ais->type17.spare         = UBITS(38, 2);
-	ais->type17.lon		= UBITS(40, 18);
-	ais->type17.lat		= UBITS(58, 17);
-	//ais->type17.spare	        = UBITS(75, 4);
+	ais->type17.lon		= SBITS(40, 18);
+	ais->type17.lat		= SBITS(58, 17);
+	//ais->type17.spare	        = UBITS(75, 5);
 	ais->type17.bitcount        = bitlen - 80;
 	(void)memcpy(ais->type17.bitdata,
 		     (char *)bits + (80 / CHAR_BIT),
@@ -1098,6 +1085,5 @@ bool ais_binary_decode(const struct gpsd_errout_t *errout,
     /* data is fully decoded */
     return true;
 }
-/*@ -charint @*/
 
 /* driver_ais.c ends here */
