@@ -1,4 +1,7 @@
-/* $Id: driver_italk.h 5727 2009-07-09 04:03:54Z ckuethe $ */
+/*
+ * This file is Copyright (c) 2010 by the GPSD project
+ * BSD terms apply: see the file COPYING in the distribution root for details.
+ */
 #ifndef _GPSD_ITALK_H_
 #define _GPSD_ITALK_H_
 
@@ -21,7 +24,7 @@
 #define NODE_HOST	0x40	/* Software on your computer */
 #define NODE_GPSWB	0x60	/* GPSWorkbench seems to be HOST|ITRAX */
 
-/* XXX These defines will likely be replaced by an enum
+/* FIX-ME: These defines will likely be replaced by an enum
  * once I map every message to the task that sent it.
  */
 /* System controller on the receiver */
@@ -127,18 +130,56 @@
 #define FIXINFO_FLAG_FIRSTFIX		0x4000
 
 /* PRN_STATUS */
-#define PRN_FLAG_FOUND  		0x0001
-#define PRN_FLAG_TRACKING 		0x0002
-#define PRN_FLAG_USE_IN_NAV 		0x0004
+#define PRN_FLAG_FOUND			0x0001
+#define PRN_FLAG_TRACKING		0x0002
+#define PRN_FLAG_USE_IN_NAV		0x0004
 
 /* UTC_IONO_MODEL */
-#define UTC_IONO_MODEL_UTCVALID  	0x0001
-#define UTC_IONO_MODEL_IONOVALID 	0x0002
+#define UTC_IONO_MODEL_UTCVALID 	0x0001
+#define UTC_IONO_MODEL_IONOVALID	0x0002
 
 /* SUBFRAME */
 #define SUBFRAME_WORD_FLAG_MASK		0x03ff
 #define SUBFRAME_GPS_PREAMBLE_INVERTED  0x0400
 
+/* PSEUDO */
+#define PSEUDO_OBS_DOPPLER_OK			0x0001
+#define PSEUDO_OBS_PSEUDORANGE_OK		0x0002
+#define PSEUDO_OBS_TOW_OK			0x0004
+#define PSEUDO_OBS_PRN_OK			0x0008
+#define PSEUDO_OBS_ELEV_OK			0x0010
+#define PSEUDO_OBS_SNR_OK			0x0020
+#define PSEUDO_OBS_SV_HEALTHY			0x0040
+#define PSEUDO_OBS_NO_CROSS_CORR		0x0080
+#define PSEUDO_OBS_DATA_EXISTS			0x0100
+#define PSEUDO_OBS_DATA_GOOD			0x0200
+#define PSEUDO_OBS_BIT_LOCK			0x0400
+#define PSEUDO_OBS_FIRST_MEAS			0x0800
+#define PSEUDO_OBS_RAIM_P_OK			0x1000
+#define PSEUDO_OBS_RAIM_V_OK			0x2000
+#define PSEUDO_OBS_RAIM_T_OK			0x4000
+#define PSEUDO_OBS_PLL				0x8000
+#define PSEUDO_OBS_MEAS_OK		( PSEUDO_OBS_ELEV_OK | PSEUDO_OBS_SNR_OK | PSEUDO_OBS_PRN_OK | PSEUDO_OBS_NO_CROSS_CORR | PSEUDO_OBS_SV_HEALTHY | PSEUDO_OBS_DATA_EXISTS | PSEUDO_OBS_DATA_GOOD | PSEUDO_OBS_PSEUDORANGE_OK )
+#define PSEUDO_OBS_DOPPLER_MEAS_OK	( PSEUDO_OBS_ELEV_OK | PSEUDO_OBS_SNR_OK | PSEUDO_OBS_PRN_OK | PSEUDO_OBS_NO_CROSS_CORR | PSEUDO_OBS_SV_HEALTHY | PSEUDO_OBS_DATA_EXISTS | PSEUDO_OBS_DATA_GOOD | PSEUDO_OBS_DOPPLER_OK )
+
+#define PSEUDO_TOW_WEEK_OK			0x0001
+#define PSEUDO_TOW_OK				0x0002
+#define PSEUDO_RESYNCH				0x0004
+#define PSEUDO_FIRST_MEAS			0x0008
+#define PSEUDO_UNSCHEDULED			0x0010
+
+#define PSEUDO_OBS_CORRECTED_AMBIGUOUS		0x0001
+#define PSEUDO_OBS_CORRECTED_BY_SMOOTHING	0x0002
+#define PSEUDO_OBS_CORRECTED_BY_IONO		0x0008
+#define PSEUDO_OBS_CORRECTED_BY_TROPO		0x0010
+#define PSEUDO_OBS_CORRECTED_BY_FAST_CORR	0x0020
+#define PSEUDO_OBS_CORRECTED_BY_DGPS		0x0040
+#define PSEUDO_OBS_CORRECTED_BY_SLOW_CORR	0x0080
+#define PSEUDO_OBS_CORRECTED_BY_WAAS_IONO	0x0100
+#define PSEUDO_OBS_CORR_POSSIBLE_XCORR		0x4000
+#define PSEUDO_OBS_CORR_FRAME_LOCK		0x8000
+#define PSEUDO_OBS_CORRECTED_BY_WAAS	( PSEUDO_OBS_CORRECTED_BY_WAAS_IONO | PSEUDO_OBS_CORRECTED_BY_FAST_CORR)
+
 /* MEMCTRL */
 #define MEM_WRITE		0x0002
 #define MEM_READD		0x0003
