@@ -469,7 +469,7 @@ static int nmeaid_to_prn(char *talker, int satnum)
      *   55..64: not used (might be assigned to further SBAS systems)
      *   65..88: GLONASS
      *   89..96: GLONASS (future extensions?)
-     *   97..192: not used
+     *   97..192: not used (SBAS PRNs 120-151 fall in here)
      *   193..195: QZSS
      *   196..200: QZSS (future extensions?)
      *   201..235: Beidou
@@ -495,10 +495,10 @@ static int nmeaid_to_prn(char *talker, int satnum)
 	    satnum += 200;
 	else if (talker[0] == 'G' && talker[1] == 'B')
 	    satnum += 200;
-	/* GLONASS reports don't seem to do this, but better safe than sorry */
+	/* GLONASS GL doesn't seem to do this, but better safe than sorry */
 	if (talker[0] == 'G' && (talker[1] == 'L' || talker[1] == 'N'))
 	    satnum += 37;
-	/* QZSS sentences have not been seen in the wild yet */
+	/* QZSS */
 	if (talker[0] == 'Q' && talker[1] == 'Z')
 	    satnum += 193;
     }
@@ -596,14 +596,28 @@ static gps_mask_t processGSV(int count, char *field[],
      * <repeat for up to 4 satellites per sentence>
      * There my be up to three GSV sentences in a data packet
      *
-     * Can occur with talker ID GP (GNSS), GL (GLONASS), GN (GLONASS),
-     *  BD (Beidou), or QZ (QZSS). GL is to be used when GSVs are mixed
-     * contaiuning GLONASS, GN when GSVs contain GLONASS only. In the
-     * GLONASS version sat IDs run from 65-96 (NMEA0183 standardizes
-     * this). At least one GPS, the BU-353 GLONASS, emits a GPGSV set
-     * followed by a GLGSV set.  We have also seen a SiRF-IV variant
-     * that emits GPGSV followed by BDGSV. We need to combine these.
+     * Can occur with talker IDs:
+     *   BD (Beidou),
+     *   GA (Galileo),
+     *   GB (Beidou),
+     *   GL (GLONASS),
+     *   GN (GLONASS, any combination GNSS),
+     *   GP (GPS, SBAS, QZSS),
+     *   QZ (QZSS).
+     *
+     * GL may to be used when GSVs are mixed containing GLONASS, GN maybe
+     * used when GSVs contain GLONASS only.  Usage is inconsistent.
+     *
+     * In the GLONASS version sat IDs run from 65-96 (NMEA0183 standardizes
+     * this). At least two GPS, the BU-353 GLONASS and the u-blox NEO-M8N,
+     * emit a GPGSV set followed by a GLGSV set.  We have also seen a
+     * SiRF-IV variant that emits GPGSV followed by BDGSV. We need to
+     * combine these.
+     *
+     * NMEA 4.1 adds a signal-ID field just before the checksum. First
+     * seen in May 2015 on a u-blox M8,
      */
+
     int n, fldnum;
     if (count <= 3) {
 	gpsd_log(&session->context->errout, LOG_WARN,
@@ -613,7 +627,11 @@ static gps_mask_t processGSV(int count, char *field[],
 	session->gpsdata.satellites_visible = 0;
 	return ONLINE_SET;
     }
-    if (count % 4 != 0) {
+    /*
+     * This check used to be !=0, but we have loosen it a little to let by
+     * NMEA 4.1 GSVs with an extra signal-ID field at the end.  
+     */
+    if (count % 4 > 1) {
 	gpsd_log(&session->context->errout, LOG_WARN,
 		 "malformed GPGSV - fieldcount %d %% 4 != 0\n",
 		 count);
@@ -629,8 +647,8 @@ static gps_mask_t processGSV(int count, char *field[],
 	gpsd_zero_satellites(&session->gpsdata);
 	return ONLINE_SET;
     } else if (session->nmea.part == 1) {
-	/* 
-	 * might have gone from GPGSV to GLGSV/BDGSV/QZGSV, 
+	/*
+	 * might have gone from GPGSV to GLGSV/BDGSV/QZGSV,
 	 * in which case accumulate
 	 */
 	if (session->nmea.last_gsv_talker == '\0' || GSV_TALKER == session->nmea.last_gsv_talker) {
@@ -951,6 +969,65 @@ static gps_mask_t processDBT(int c UNUSED, char *field[],
     return mask;
 }
 
+static gps_mask_t processTXT(int count, char *field[],
+			       struct gps_device_t *session)
+/* GPS Text message */
+{
+    /*
+     * $GNTXT,01,01,01,PGRM inv format*2A
+     * 1                   Number of sentences for full data
+     * 1                   Sentence 1 of 1
+     * 01                  Message type
+     *       00 - error
+     *       01 - warning
+     *       02 - notice
+     *       07 - user
+     * PGRM inv format     ASCII text
+     *
+     * Can occur with talker IDs:
+     *   BD (Beidou),
+     *   GA (Galileo),
+     *   GB (Beidou),
+     *   GL (GLONASS),
+     *   GN (GLONASS, any combination GNSS),
+     *   GP (GPS, SBAS, QZSS),
+     *   QZ (QZSS).
+     */
+    gps_mask_t mask = 0;
+    int msgType = 0;
+    char *msgType_txt = "Unknown";
+
+    if ( 5 != count) {
+      return 0;
+    }
+
+    /* set something, so it won't look like an unknown sentence */
+    mask |= ONLINE_SET;
+
+    msgType = atoi(field[3]);
+
+    switch ( msgType ) {
+    case 0:
+	msgType_txt = "Error";
+        break;
+    case 1:
+	msgType_txt = "Warning";
+        break;
+    case 2:
+	msgType_txt = "Notice";
+        break;
+    case 7:
+	msgType_txt = "User";
+        break;
+    }
+
+    /* maximum text lenght unknown, guess 80 */
+    gpsd_log(&session->context->errout, LOG_WARN,
+	     "TXT: %.10s: %.80s\n",
+             msgType_txt, field[4]);
+    return mask;
+}
+
 #ifdef TNT_ENABLE
 static gps_mask_t processTNTHTM(int c UNUSED, char *field[],
 				struct gps_device_t *session)
@@ -1174,6 +1251,26 @@ static gps_mask_t processMTK3301(int c UNUSED, char *field[],
 
     msg = atoi(&(session->nmea.field[0])[4]);
     switch (msg) {
+    case 001:			/* ACK / NACK */
+	reason = atoi(field[2]);
+	if (atoi(field[1]) == -1)
+	    gpsd_log(&session->context->errout, LOG_WARN,
+		     "MTK NACK: unknown sentence\n");
+	else if (reason < 3) {
+	    const char *mtk_reasons[] = {
+		"Invalid",
+		"Unsupported",
+		"Valid but Failed",
+		"Valid success"
+	    };
+	    gpsd_log(&session->context->errout, LOG_WARN,
+		     "MTK NACK: %s, reason: %s\n",
+		     field[1], mtk_reasons[reason]);
+	}
+	else
+	    gpsd_log(&session->context->errout, LOG_DATA,
+		     "MTK ACK: %s\n", field[1]);
+	return ONLINE_SET;
     case 424:			/* PPS pulse width response */
 	/*
 	 * Response will look something like: $PMTK424,0,0,1,0,69*12
@@ -1222,6 +1319,8 @@ static gps_mask_t processMTK3301(int c UNUSED, char *field[],
 	 * 16368000 cycles/second = 1/128 seconds = 7.8125
 	 * milliseconds"
 	 */
+
+	/* too short?  Make it longer */
 	if (atoi(field[5]) < 127875)
 	    (void)nmea_send(session, "$PMTK324,0,0,1,0,127875");
 	return ONLINE_SET;
@@ -1230,27 +1329,9 @@ static gps_mask_t processMTK3301(int c UNUSED, char *field[],
 	(void)strlcat(session->subtype, "-", sizeof(session->subtype));
 	(void)strlcat(session->subtype, field[2], sizeof(session->subtype));
 	return ONLINE_SET;
-    case 001:			/* ACK / NACK */
-	reason = atoi(field[2]);
-	if (atoi(field[1]) == -1)
-	    gpsd_log(&session->context->errout, LOG_WARN,
-		     "MTK NACK: unknown sentence\n");
-	else if (reason < 3) {
-	    const char *mtk_reasons[] = {
-		"Invalid",
-		"Unsupported",
-		"Valid but Failed",
-		"Valid success"
-	    };
-	    gpsd_log(&session->context->errout, LOG_WARN,
-		     "MTK NACK: %s, reason: %s\n",
-		     field[1], mtk_reasons[reason]);
-	}
-	else
-	    gpsd_log(&session->context->errout, LOG_WARN,
-		     "MTK ACK: %s\n", field[1]);
-	return ONLINE_SET;
     default:
+	gpsd_log(&session->context->errout, LOG_PROG,
+	     "MTK: unknown msg: %d\n", msg);
 	return ONLINE_SET;		/* ignore */
     }
 }
@@ -1262,7 +1343,6 @@ static gps_mask_t processMTK3301(int c UNUSED, char *field[],
  *
  **************************************************************************/
 
-/*@ -mayaliasunique @*/
 gps_mask_t nmea_parse(char *sentence, struct gps_device_t * session)
 /* parse an NMEA sentence, unpack it into a session structure */
 {
@@ -1275,7 +1355,6 @@ gps_mask_t nmea_parse(char *sentence, struct gps_device_t * session)
 	bool cycle_continue;	/* cycle continuer? */
 	nmea_decoder decoder;
     } nmea_phrase[] = {
-	/*@ -nullassign @*/
 	{"PGRMC", 0, false, NULL},	/* ignore Garmin Sensor Config */
 	{"PGRME", 7, false, processPGRME},
 	{"PGRMI", 0, false, NULL},	/* ignore Garmin Sensor Init */
@@ -1296,30 +1375,34 @@ gps_mask_t nmea_parse(char *sentence, struct gps_device_t * session)
 	     * 4. The mode is changed back to NMEA, resulting in an
 	     *    infinite loop.
 	     */
-	{"RMC", 8,  false, processRMC},
+	{"DBT", 7,  true,  processDBT},
+	{"GBS", 7,  false, processGBS},
 	{"GGA", 13, false, processGGA},
-	{"GST", 8,  false, processGST},
 	{"GLL", 7,  false, processGLL},
 	{"GSA", 17, false, processGSA},
+	{"GST", 8,  false, processGST},
 	{"GSV", 0,  false, processGSV},
-	{"VTG", 0,  false, NULL},	/* ignore Velocity Track made Good */
-	{"ZDA", 4,  false, processZDA},
-	{"GBS", 7,  false, processGBS},
         {"HDT", 1,  false, processHDT},
-	{"DBT", 7,  true,  processDBT},
-#ifdef TNT_ENABLE
-	{"PTNTHTM", 9, false, processTNTHTM},
-#endif /* TNT_ENABLE */
-#ifdef ASHTECH_ENABLE
-	{"PASHR", 3, false, processPASHR},	/* general handler for Ashtech */
-#endif /* ASHTECH_ENABLE */
 #ifdef OCEANSERVER_ENABLE
 	{"OHPR", 18, false, processOHPR},
 #endif /* OCEANSERVER_ENABLE */
-	    /*@ +nullassign @*/
+#ifdef ASHTECH_ENABLE
+	{"PASHR", 3, false, processPASHR},	/* general handler for Ashtech */
+#endif /* ASHTECH_ENABLE */
 #ifdef MTK3301_ENABLE
 	{"PMTK", 3,  false, processMTK3301},
+        /* for some reason thhe parser no longer triggering on leading chars */
+	{"PMTK001", 3,  false, processMTK3301},
+	{"PMTK424", 3,  false, processMTK3301},
+	{"PMTK705", 3,  false, processMTK3301},
 #endif /* MTK3301_ENABLE */
+#ifdef TNT_ENABLE
+	{"PTNTHTM", 9, false, processTNTHTM},
+#endif /* TNT_ENABLE */
+	{"RMC", 8,  false, processRMC},
+	{"TXT", 5,  false, processTXT},
+	{"ZDA", 4,  false, processZDA},
+	{"VTG", 0,  false, NULL},	/* ignore Velocity Track made Good */
     };
 
     int count;
@@ -1343,7 +1426,6 @@ gps_mask_t nmea_parse(char *sentence, struct gps_device_t * session)
 	return ONLINE_SET;
     }
 
-    /*@ -usedef @*//* splint 3.1.1 seems to have a bug here */
     /* make an editable copy of the sentence */
     (void)strlcpy((char *)session->nmea.fieldcopy, sentence, sizeof(session->nmea.fieldcopy) - 1);
     /* discard the checksum part */
@@ -1362,13 +1444,11 @@ gps_mask_t nmea_parse(char *sentence, struct gps_device_t * session)
     /* while there is a search string and we haven't run off the buffer... */
     while ((p != NULL) && (p <= t)) {
 	session->nmea.field[count] = p;	/* we have a field. record it */
-	/*@ -compdef @*/
 	if ((p = strchr(p, ',')) != NULL) {	/* search for the next delimiter */
 	    *p = '\0';		/* replace it with a NUL */
 	    count++;		/* bump the counters and continue */
 	    p++;
 	}
-	/*@ +compdef @*/
     }
 
     /* point remaining fields at empty string, just in case */
@@ -1378,7 +1458,7 @@ gps_mask_t nmea_parse(char *sentence, struct gps_device_t * session)
 		    sizeof(session->nmea.field[0])); i++)
 	session->nmea.field[i] = e;
 
-    /* sentences handlers will tell us whren they have fractional time */
+    /* sentences handlers will tell us when they have fractional time */
     session->nmea.latch_frac_time = false;
 
     /* dispatch on field zero, the sentence tag */
@@ -1507,7 +1587,6 @@ gps_mask_t nmea_parse(char *sentence, struct gps_device_t * session)
     return retval;
 }
 
-/*@ +mayaliasunique @*/
 #endif /* NMEA_ENABLE */
 
 void nmea_add_checksum(char *sentence)
