@@ -13,22 +13,18 @@
 #include <time.h>
 #include <math.h>
 #include <fcntl.h>
-#ifndef S_SPLINT_S
 #include <unistd.h>
 #include <sys/socket.h>
 #include <net/if.h>
 #include <sys/ioctl.h>
-#endif /* S_SPLINT_S */
 
 #include "gpsd.h"
 #if defined(NMEA2000_ENABLE)
 #include "driver_nmea2000.h"
 #include "bits.h"
 
-#ifndef S_SPLINT_S
 #include <linux/can.h>
 #include <linux/can/raw.h>
-#endif /* S_SPLINT_S */
 
 #define LOG_FILE 1
 #define NMEA2000_NETS 4
@@ -51,7 +47,6 @@ typedef struct PGN
     const char    *name;
     } PGN;
 
-/*@-nullassign@*/
 
 #if LOG_FILE
 FILE *logFile = NULL;
@@ -67,7 +62,7 @@ static int scale_int(int32_t var, const int64_t factor)
 
         ret   = var;
         ret  *= factor;
-        /*@i1@*/ret >>= 32;
+        ret >>= 32;
 
         return((int)ret);
 }
@@ -76,7 +71,6 @@ static void print_data(struct gps_context_t *context,
 		       unsigned char *buffer, int len, PGN *pgn)
 {
 #ifdef LIBGPS_DEBUG
-    /*@-bufferoverflowhigh@*/
     if ((libgps_debuglevel >= LOG_IO) != 0) {
 	int   l1, l2, ptr;
 	char  bu[128];
@@ -96,7 +90,6 @@ static void print_data(struct gps_context_t *context,
         }
         gpsd_log(&context->errout, LOG_IO,"%s\n", bu);
     }
-    /*@+bufferoverflowhigh@*/
 #else
     (void)context;
     (void)buffer;
@@ -112,7 +105,7 @@ static gps_mask_t get_mode(struct gps_device_t *session)
     } else {
         session->newdata.mode = MODE_NOT_SEEN;
     }
-    
+
     if (session->driver.nmea2000.mode_valid & 2) {
         return MODE_SET | USED_IS;
     } else {
@@ -273,10 +266,8 @@ static gps_mask_t hnd_129025(unsigned char *bu, int len, PGN *pgn, struct gps_de
     gpsd_log(&session->context->errout, LOG_DATA,
 	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
 
-    /*@-type@*//* splint has a bug here */
     session->newdata.latitude = getles32(bu, 0) * 1e-7;
     session->newdata.longitude = getles32(bu, 4) * 1e-7;
-    /*@+type@*/
 
     return LATLON_SET | get_mode(session);
 }
@@ -293,10 +284,8 @@ static gps_mask_t hnd_129026(unsigned char *bu, int len, PGN *pgn, struct gps_de
 
     session->driver.nmea2000.sid[0]  =  bu[0];
 
-    /*@-type@*//* splint has a bug here */
     session->newdata.track           =  getleu16(bu, 2) * 1e-4 * RAD_2_DEG;
     session->newdata.speed           =  getleu16(bu, 4) * 1e-2;
-    /*@+type@*/
 
     return SPEED_SET | TRACK_SET | get_mode(session);
 }
@@ -317,9 +306,7 @@ static gps_mask_t hnd_126992(unsigned char *bu, int len, PGN *pgn, struct gps_de
     //sid        = bu[0];
     //source     = bu[1] & 0x0f;
 
-    /*@-type@*//* splint has a bug here */
     session->newdata.time = getleu16(bu, 2)*24*60*60 + getleu32(bu, 4)/1e4;
-    /*@+type@*/
 
     return TIME_SET | get_mode(session);
 }
@@ -356,11 +343,9 @@ static gps_mask_t hnd_129539(unsigned char *bu, int len, PGN *pgn, struct gps_de
 
     session->driver.nmea2000.mode    = mode_tab[act_mode];
 
-    /*@-type@*//* splint has a bug here */
     session->gpsdata.dop.hdop        = getleu16(bu, 2) * 1e-2;
     session->gpsdata.dop.vdop        = getleu16(bu, 4) * 1e-2;
     session->gpsdata.dop.tdop        = getleu16(bu, 6) * 1e-2;
-    /*@+type@*/
     mask                            |= DOP_SET;
 
     gpsd_log(&session->context->errout, LOG_DATA,
@@ -395,11 +380,9 @@ static gps_mask_t hnd_129540(unsigned char *bu, int len, PGN *pgn, struct gps_de
         int    svt;
         double azi, elev, snr;
 
-	/*@-type@*//* splint has a bug here */
         elev  = getles16(bu, 3+12*l1+1) * 1e-4 * RAD_2_DEG;
         azi   = getleu16(bu, 3+12*l1+3) * 1e-4 * RAD_2_DEG;
         snr   = getles16(bu, 3+12*l1+5) * 1e-2;
-	/*@+type@*/
 
         svt   = (int)(bu[3+12*l1+11] & 0x0f);
 
@@ -431,20 +414,14 @@ static gps_mask_t hnd_129029(unsigned char *bu, int len, PGN *pgn, struct gps_de
     mask                             = 0;
     session->driver.nmea2000.sid[3]  = bu[0];
 
-    /*@-type@*//* splint has a bug here */
     session->newdata.time            = getleu16(bu,1) * 24*60*60 + getleu32(bu, 3)/1e4;
-    /*@+type@*/
     mask                            |= TIME_SET;
 
-    /*@-type@*//* splint has a bug here */
     session->newdata.latitude        = getles64(bu, 7) * 1e-16;
     session->newdata.longitude       = getles64(bu, 15) * 1e-16;
-    /*@+type@*/
     mask                            |= LATLON_SET;
 
-    /*@-type@*//* splint has a bug here */
     session->newdata.altitude        = getles64(bu, 23) * 1e-6;
-    /*@+type@*/
     mask                            |= ALTITUDE_SET;
 
 //  printf("mode %x %x\n", (bu[31] >> 4) & 0x0f, bu[31]);
@@ -469,17 +446,13 @@ static gps_mask_t hnd_129029(unsigned char *bu, int len, PGN *pgn, struct gps_de
     }
     mask                            |= STATUS_SET;
 
-    /*@-type@*//* splint has a bug here */
     session->gpsdata.separation      = getles32(bu, 38) / 100.0;
-    /*@+type@*/
     session->newdata.altitude       -= session->gpsdata.separation;
 
     session->gpsdata.satellites_used = (int)bu[33];
 
-    /*@-type@*//* splint has a bug here */
     session->gpsdata.dop.hdop        = getleu16(bu, 34) * 0.01;
     session->gpsdata.dop.pdop        = getleu16(bu, 36) * 0.01;
-    /*@+type@*/
     mask                            |= DOP_SET;
 
     return mask | get_mode(session);
@@ -509,7 +482,7 @@ static gps_mask_t hnd_129038(unsigned char *bu, int len, PGN *pgn, struct gps_de
 	ais->type1.radio     = (unsigned int) (getleu32(bu, 18) & 0x7ffff);
 	ais->type1.heading   = (unsigned int)  ais_direction((unsigned int)getleu16(bu, 21), 1.0);
 	ais->type1.turn      =                 ais_turn_rate((int)getles16(bu, 23));
-	ais->type1.status    = (unsigned int) ((bu[25] >> 0) & 0xff);
+	ais->type1.status    = (unsigned int) ((bu[25] >> 0) & 0x0f);
 	ais->type1.maneuver  = 0; /* Not transmitted ???? */
 	decode_ais_channel_info(bu, len, 163, session);
 
@@ -540,7 +513,7 @@ static gps_mask_t hnd_129039(unsigned char *bu, int len, PGN *pgn, struct gps_de
 	ais->type18.course   = (unsigned int)  ais_direction((unsigned int) getleu16(bu, 14), 10.0);
 	ais->type18.speed    = (unsigned int) (getleu16(bu, 16) * MPS_TO_KNOTS * 0.01 / 0.1);
 	ais->type18.radio    = (unsigned int) (getleu32(bu, 18) & 0x7ffff);
-	ais->type18.heading  = (unsigned int)  ais_direction((unsigned int) getleu16(bu, 21), 1.0);    
+	ais->type18.heading  = (unsigned int)  ais_direction((unsigned int) getleu16(bu, 21), 1.0);
 	ais->type18.reserved = 0;
 	ais->type18.regional = (unsigned int) ((bu[24] >> 0) & 0x03);
 	ais->type18.cs	     = (bool)         ((bu[24] >> 2) & 0x01);
@@ -616,6 +589,66 @@ static gps_mask_t hnd_129040(unsigned char *bu, int len, PGN *pgn, struct gps_de
 }
 
 
+/*
+ *   PGN 129793: AIS UTC and Date Report
+ */
+static gps_mask_t hnd_129793(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
+{
+    struct ais_t *ais;
+
+    ais =  &session->gpsdata.ais;
+    print_data(session->context, bu, len, pgn);
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
+
+    if (decode_ais_header(session->context, bu, len, ais, 0xffffffffU) != 0) {
+        uint32_t  time;
+        uint32_t  date;
+	time_t    date1;
+        struct tm date2;
+
+        ais->type4.lon          = (int)          scale_int(getles32(bu, 5), (int64_t)(SHIFT32 *.06L));
+	ais->type4.lat          = (int)          scale_int(getles32(bu, 9), (int64_t)(SHIFT32 *.06L));
+	ais->type4.accuracy     = (bool)         ((bu[13] >> 0) & 0x01);
+	ais->type4.raim         = (bool)         ((bu[13] >> 1) & 0x01);
+
+	time = getleu32(bu, 14);
+	if (time != 0xffffffff) {
+	    time                = time / 10000;
+	    ais->type4.second   = time % 60; time = time / 60;
+	    ais->type4.minute   = time % 60; time = time / 60;
+	    ais->type4.hour     = time % 24;
+	} else {
+	    ais->type4.second   = AIS_SECOND_NOT_AVAILABLE;
+	    ais->type4.minute   = AIS_MINUTE_NOT_AVAILABLE;
+	    ais->type4.hour     = AIS_HOUR_NOT_AVAILABLE;
+	}
+
+        ais->type4.radio        = (unsigned int) (getleu32(bu, 18) & 0x7ffff);
+
+	date = getleu16(bu, 21);
+	if (date != 0xffff) {
+	    date1 = (time_t)date * (24L *60L *60L);
+	    (void) gmtime_r(&date1, &date2);
+            ais->type4.year     = (unsigned int) (date2.tm_year+1900);
+            ais->type4.month    = (unsigned int) (date2.tm_mon+1);
+	    ais->type4.day      = (unsigned int) (date2.tm_mday);
+	} else {
+	    ais->type4.day      = AIS_DAY_NOT_AVAILABLE;
+	    ais->type4.month    = AIS_MONTH_NOT_AVAILABLE;
+	    ais->type4.year     = AIS_YEAR_NOT_AVAILABLE;
+	}
+
+	ais->type4.epfd         = (unsigned int) ((bu[23] >> 4) & 0x0f);
+
+        decode_ais_channel_info(bu, len, 163, session);
+
+	return(ONLINE_SET | AIS_SET);
+    }
+    return(0);
+}
+
+
 /*
  *   PGN 129794: AIS Class A Static and Voyage Related Data
  */
@@ -634,6 +667,7 @@ static gps_mask_t hnd_129794(unsigned char *bu, int len, PGN *pgn, struct gps_de
 	uint32_t  time;
 	time_t    date1;
         struct tm date2;
+        int       cpy_stop;
 
         ais->type5.ais_version   = (unsigned int) ((bu[73] >> 0) & 0x03);
 	ais->type5.imo           = (unsigned int)  getleu32(bu,  5);
@@ -671,18 +705,48 @@ static gps_mask_t hnd_129794(unsigned char *bu, int len, PGN *pgn, struct gps_de
 	ais->type5.draught       = (unsigned int) (getleu16(bu, 51)/10);
 	ais->type5.dte           = (unsigned int) ((bu[73] >> 6) & 0x01);
 
-	for (l=0;l<7;l++) {
-	    ais->type5.callsign[l] = (char) bu[9+l];
+	for (l=0,cpy_stop=0;l<7;l++) {
+            char next;
+
+	    next = (char) bu[9+l];
+	    if ((next < ' ') || (next > 0x7e)) {
+	        cpy_stop = 1;
+	    }
+	    if (cpy_stop == 0) {
+	        ais->type5.callsign[l] = next;
+	    } else {
+	        ais->type5.callsign[l] = 0;
+	    }
 	}
 	ais->type5.callsign[7]   = (char) 0;
 
-	for (l=0;l<AIS_SHIPNAME_MAXLEN;l++) {
-	    ais->type5.shipname[l] = (char) bu[16+l];
+	for (l=0,cpy_stop=0;l<AIS_SHIPNAME_MAXLEN;l++) {
+	    char next;
+
+	    next = (char) bu[16+l];
+	    if ((next < ' ') || (next > 0x7e)) {
+	        cpy_stop = 1;
+	    }
+	    if (cpy_stop == 0) {
+	        ais->type5.shipname[l] = next;
+	    } else {
+	        ais->type5.shipname[l] = 0;
+	    }
 	}
 	ais->type5.shipname[AIS_SHIPNAME_MAXLEN] = (char) 0;
 
-	for (l=0;l<20;l++) {
-	    ais->type5.destination[l] = (char) bu[53+l];
+	for (l=0,cpy_stop=0;l<20;l++) {
+            char next;
+
+	    next = (char) bu[53+l];
+	    if ((next < ' ') || (next > 0x7e)) {
+	        cpy_stop = 1;
+	    }
+	    if (cpy_stop == 0) {
+	        ais->type5.destination[l] = next;
+	    } else {
+	        ais->type5.destination[l] = 0;
+	    }
 	}
 	ais->type5.destination[20] = (char) 0;
 #if NMEA2000_DEBUG_AIS
@@ -698,7 +762,7 @@ static gps_mask_t hnd_129794(unsigned char *bu, int len, PGN *pgn, struct gps_de
 	       ais->type5.to_starboard,
 	       ais->type5.draught/10.0);
 	printf("AIS: arival:%-20.20s at %02u-%02u-%04d %02u:%0u\n",
-	       ais->type5.destination, 
+	       ais->type5.destination,
 	       ais->type5.day,
 	       ais->type5.month,
 	       date2.tm_year+1900,
@@ -973,10 +1037,9 @@ static gps_mask_t hnd_127245(unsigned char *bu, int len, PGN *pgn, struct gps_de
 static gps_mask_t hnd_127250(unsigned char *bu, int len, PGN *pgn, struct gps_device_t *session)
 {
     int aux;
-  
+
     print_data(session->context, bu, len, pgn);
 
-    /*@-type@*/
     session->gpsdata.attitude.heading = getleu16(bu, 1) * RAD_2_DEG * 0.0001;
 //  printf("ATT 0:%8.3f\n",session->gpsdata.attitude.heading);
     aux = getles16(bu, 3);
@@ -988,7 +1051,6 @@ static gps_mask_t hnd_127250(unsigned char *bu, int len, PGN *pgn, struct gps_de
     if (aux != 0x07fff) {
         session->gpsdata.attitude.heading += aux * RAD_2_DEG * 0.0001;
     }
-    /*@+type@*/
 //  printf("ATT 2:%8.3f %6x\n",session->gpsdata.attitude.heading, aux);
     session->gpsdata.attitude.mag_st = '\0';
     session->gpsdata.attitude.pitch = NAN;
@@ -1055,7 +1117,7 @@ static gps_mask_t hnd_128267(unsigned char *bu, int len, PGN *pgn, struct gps_de
     session->gpsdata.attitude.gyro_x = NAN;
     session->gpsdata.attitude.gyro_y = NAN;
     session->gpsdata.attitude.temp = NAN;
-    /*@i@*/session->gpsdata.attitude.depth = getleu32(bu, 1) *.01;
+    session->gpsdata.attitude.depth = getleu32(bu, 1) *.01;
 
     gpsd_log(&session->context->errout, LOG_DATA,
 	     "pgn %6d(%3d):\n", pgn->pgn, session->driver.nmea2000.unit);
@@ -1147,7 +1209,6 @@ static gps_mask_t hnd_130311(unsigned char *bu, int len, PGN *pgn, struct gps_de
 }
 
 
-/*@-usereleased@*/
 static const char msg_059392[] = {"ISO  Acknowledgment"};
 static const char msg_060928[] = {"ISO  Address Claim"};
 static const char msg_126208[] = {"NMEA Command/Request/Acknowledge"};
@@ -1169,6 +1230,7 @@ static const char msg_129540[] = {"GNSS Satellites in View"};
 static const char msg_129038[] = {"AIS  Class A Position Report"};
 static const char msg_129039[] = {"AIS  Class B Position Report"};
 static const char msg_129040[] = {"AIS  Class B Extended Position Report"};
+static const char msg_129793[] = {"AIS  UTC and Date report"};
 static const char msg_129794[] = {"AIS  Class A Static and Voyage Related Data"};
 static const char msg_129798[] = {"AIS  SAR Aircraft Position Report"};
 static const char msg_129802[] = {"AIS  Safty Related Broadcast Message"};
@@ -1217,6 +1279,7 @@ static PGN aispgn[] = {{ 59392, 0, 0, hnd_059392, &msg_059392[0]},
 		       {129038, 1, 2, hnd_129038, &msg_129038[0]},
 		       {129039, 1, 2, hnd_129039, &msg_129039[0]},
 		       {129040, 1, 2, hnd_129040, &msg_129040[0]},
+		       {129793, 1, 2, hnd_129793, &msg_129793[0]},
 		       {129794, 1, 2, hnd_129794, &msg_129794[0]},
 		       {129798, 1, 2, hnd_129798, &msg_129798[0]},
 		       {129802, 1, 2, hnd_129802, &msg_129802[0]},
@@ -1256,10 +1319,8 @@ static PGN navpgn[] = {{ 59392, 0, 0, hnd_059392, &msg_059392[0]},
 		       {0     , 0, 0, NULL,       &msg_error [0]}};
 
 
-/*@+usereleased@*/
 
-/*@-immediatetrans@*/
-static /*@null@*/ PGN *search_pgnlist(unsigned int pgn, PGN *pgnlist)
+static PGN *search_pgnlist(unsigned int pgn, PGN *pgnlist)
 {
     int l1;
     PGN *work;
@@ -1276,9 +1337,7 @@ static /*@null@*/ PGN *search_pgnlist(unsigned int pgn, PGN *pgnlist)
 	}
     return work;
 }
-/*@+immediatetrans@*/
 
-/*@-nullstate -branchstate -globstate -mustfreeonly@*/
 static void find_pgn(struct can_frame *frame, struct gps_device_t *session)
 {
     unsigned int can_net;
@@ -1291,7 +1350,6 @@ static void find_pgn(struct can_frame *frame, struct gps_device_t *session)
         return;
     }
 
-    /*@ignore@*//* because the CAN include files choke splint */
     if (frame->can_id & 0x80000000) {
 	// cppcheck-suppress unreadVariable
 #ifdef __UNUSED__
@@ -1321,15 +1379,12 @@ static void find_pgn(struct can_frame *frame, struct gps_device_t *session)
 	    fprintf(logFile, "\n");
 	}
 #endif /* of if LOG_FILE */
-	/*@end@*/
 	session->driver.nmea2000.can_msgcnt += 1;
-	/*@ignore@*//* because the CAN include files choke splint */
 	source_pgn = (frame->can_id >> 8) & 0x1ffff;
 #ifdef __UNUSED__
 	source_prio = (frame->can_id >> 26) & 0x7;
 #endif
 	source_unit = frame->can_id & 0x0ff;
-	/*@end@*/
 
 	if (((source_pgn & 0x0ff00) >> 8) < 240) {
 #ifdef __UNUSED__
@@ -1342,14 +1397,14 @@ static void find_pgn(struct can_frame *frame, struct gps_device_t *session)
 #endif
 	}
 
-	if (session->driver.nmea2000.unit_valid == 0) {
+	if (!session->driver.nmea2000.unit_valid) {
 	    unsigned int l1, l2;
-	    
+
 	    for (l1=0;l1<NMEA2000_NETS;l1++) {
 	        for (l2=0;l2<NMEA2000_UNITS;l2++) {
 		    if (session == nmea2000_units[l1][l2]) {
 		        session->driver.nmea2000.unit = l2;
-		        session->driver.nmea2000.unit_valid = 1;
+		        session->driver.nmea2000.unit_valid = true;
 			session->driver.nmea2000.can_net = l1;
 			can_net = l1;
 		    }
@@ -1357,9 +1412,9 @@ static void find_pgn(struct can_frame *frame, struct gps_device_t *session)
 	    }
 	}
 
-	if (session->driver.nmea2000.unit_valid == 0) {
+	if (!session->driver.nmea2000.unit_valid) {
 	    session->driver.nmea2000.unit = source_unit;
-	    session->driver.nmea2000.unit_valid = 1;
+	    session->driver.nmea2000.unit_valid = true;
 	    nmea2000_units[can_net][source_unit] = session;
 	}
 
@@ -1395,16 +1450,15 @@ static void find_pgn(struct can_frame *frame, struct gps_device_t *session)
 		    gpsd_log(&session->context->errout, LOG_DATA,
 			     "pgn %6d:%s \n", work->pgn, work->name);
 		    session->driver.nmea2000.workpgn = (void *) work;
-		    /*@i1@*/session->lexer.outbuflen =  frame->can_dlc & 0x0f;
+		    session->lexer.outbuflen =  frame->can_dlc & 0x0f;
 		    for (l2=0;l2<session->lexer.outbuflen;l2++) {
-		        /*@i3@*/session->lexer.outbuffer[l2]= frame->data[l2];
+		        session->lexer.outbuffer[l2]= frame->data[l2];
 		    }
-		}
-		/*@i2@*/else if ((frame->data[0] & 0x1f) == 0) {
+		} else if ((frame->data[0] & 0x1f) == 0) {
 		    unsigned int l2;
 
-		    /*@i2@*/session->driver.nmea2000.fast_packet_len = frame->data[1];
-		    /*@i2@*/session->driver.nmea2000.idx = frame->data[0];
+		    session->driver.nmea2000.fast_packet_len = frame->data[1];
+		    session->driver.nmea2000.idx = frame->data[0];
 #if NMEA2000_FAST_DEBUG
 		    gpsd_log(&session->context->errout, LOG_ERROR,
 			     "Set idx    %2x    %2x %2x %6d\n",
@@ -1416,17 +1470,16 @@ static void find_pgn(struct can_frame *frame, struct gps_device_t *session)
 		    session->lexer.inbuflen = 0;
 		    session->driver.nmea2000.idx += 1;
 		    for (l2=2;l2<8;l2++) {
-		        /*@i3@*/session->lexer.inbuffer[session->lexer.inbuflen++] = frame->data[l2];
+		        session->lexer.inbuffer[session->lexer.inbuflen++] = frame->data[l2];
 		    }
 		    gpsd_log(&session->context->errout, LOG_DATA,
 			     "pgn %6d:%s \n", work->pgn, work->name);
-		}
-		/*@i2@*/else if (frame->data[0] == session->driver.nmea2000.idx) {
+		} else if (frame->data[0] == session->driver.nmea2000.idx) {
 		    unsigned int l2;
 
 		    for (l2=1;l2<8;l2++) {
 		        if (session->driver.nmea2000.fast_packet_len > session->lexer.inbuflen) {
-			    /*@i3@*/session->lexer.inbuffer[session->lexer.inbuflen++] = frame->data[l2];
+			    session->lexer.inbuffer[session->lexer.inbuflen++] = frame->data[l2];
 			}
 		    }
 		    if (session->lexer.inbuflen == session->driver.nmea2000.fast_packet_len) {
@@ -1434,7 +1487,7 @@ static void find_pgn(struct can_frame *frame, struct gps_device_t *session)
 		        gpsd_log(&session->context->errout, LOG_ERROR,
 				 "Fast done  %2x %2x %2x %2x %6d\n",
 				 session->driver.nmea2000.idx,
-				                                                   /*@i1@*/frame->data[0],
+				                                                   frame->data[0],
 				                                                   session->driver.nmea2000.unit,
 				                                                   (unsigned int) session->driver.nmea2000.fast_packet_len,
 				                                                   source_pgn);
@@ -1452,7 +1505,7 @@ static void find_pgn(struct can_frame *frame, struct gps_device_t *session)
 		    gpsd_log(&session->context->errout, LOG_ERROR,
 			     "Fast error %2x %2x %2x %2x %6d\n",
 			     session->driver.nmea2000.idx,
-			     /*@i2@*/frame->data[0],
+			     frame->data[0],
 			     session->driver.nmea2000.unit,
 			     (unsigned int) session->driver.nmea2000.fast_packet_len,
 				                                               source_pgn);
@@ -1481,7 +1534,6 @@ static void find_pgn(struct can_frame *frame, struct gps_device_t *session)
         // we got RTR or 2.0A CAN frame, not used
     }
 }
-/*@+nullstate +branchstate +globstate +mustfreeonly@*/
 
 
 static ssize_t nmea2000_get(struct gps_device_t *session)
@@ -1500,7 +1552,6 @@ static ssize_t nmea2000_get(struct gps_device_t *session)
     return 0;
 }
 
-/*@-mustfreeonly -nullstate@*/
 static gps_mask_t nmea2000_parse_input(struct gps_device_t *session)
 {
     gps_mask_t mask;
@@ -1518,11 +1569,7 @@ static gps_mask_t nmea2000_parse_input(struct gps_device_t *session)
 
     return mask;
 }
-/*@+mustfreeonly -nullstate@*/
 
-/*@+nullassign@*/
-
-#ifndef S_SPLINT_S
 
 int nmea2000_open(struct gps_device_t *session)
 {
@@ -1568,7 +1615,7 @@ int nmea2000_open(struct gps_device_t *session)
 	    return -1;
 	}
 	for (l = 0; l < NMEA2000_NETS; l++) {
-	    if (strncmp(can_interface_name[l], 
+	    if (strncmp(can_interface_name[l],
 			interface_name,
 			MIN(sizeof(interface_name), sizeof(can_interface_name[l]))) == 0) {
 	        can_net = l;
@@ -1582,7 +1629,7 @@ int nmea2000_open(struct gps_device_t *session)
 	}
     } else {
 	for (l = 0; l < NMEA2000_NETS; l++) {
-	    if (strncmp(can_interface_name[l], 
+	    if (strncmp(can_interface_name[l],
 			interface_name,
 			MIN(sizeof(interface_name), sizeof(can_interface_name[l]))) == 0) {
 	        gpsd_log(&session->context->errout, LOG_ERROR, "NMEA2000 open: CAN device duplicate open: %s .\n", interface_name);
@@ -1604,7 +1651,7 @@ int nmea2000_open(struct gps_device_t *session)
 
     /* Create the socket */
     sock = socket(PF_CAN, SOCK_RAW, CAN_RAW);
- 
+
     if (BAD_SOCKET(sock)) {
         gpsd_log(&session->context->errout, LOG_ERROR,
 		 "NMEA2000 open: can not get socket.\n");
@@ -1651,14 +1698,14 @@ int nmea2000_open(struct gps_device_t *session)
     if (unit_ptr != NULL) {
         nmea2000_units[can_net][unit_number] = session;
 	session->driver.nmea2000.unit = unit_number;
-	session->driver.nmea2000.unit_valid = 1;
+	session->driver.nmea2000.unit_valid = true;
     } else {
         strncpy(can_interface_name[can_net],
-		interface_name, 
+		interface_name,
 		MIN(sizeof(can_interface_name[0]), sizeof(interface_name)));
-	session->driver.nmea2000.unit_valid = 0;
+	session->driver.nmea2000.unit_valid = false;
 	for (l=0;l<NMEA2000_UNITS;l++) {
-	    nmea2000_units[can_net][l] = NULL;	  
+	    nmea2000_units[can_net][l] = NULL;
 	}
     }
 
@@ -1667,7 +1714,6 @@ int nmea2000_open(struct gps_device_t *session)
     session->gpsdata.dev.stopbits = 0;
     return session->gpsdata.gps_fd;
 }
-#endif /* of ifndef S_SPLINT_S */
 
 void nmea2000_close(struct gps_device_t *session)
 {
@@ -1677,6 +1723,21 @@ void nmea2000_close(struct gps_device_t *session)
 		 session->gpsdata.gps_fd, session->gpsdata.dev.path);
 	(void)close(session->gpsdata.gps_fd);
 	INVALIDATE_SOCKET(session->gpsdata.gps_fd);
+
+	if (session->driver.nmea2000.unit_valid) {
+	    unsigned int l1, l2;
+
+	    for (l1=0;l1<NMEA2000_NETS;l1++) {
+	        for (l2=0;l2<NMEA2000_UNITS;l2++) {
+		    if (session == nmea2000_units[l1][l2]) {
+		        session->driver.nmea2000.unit_valid = false;
+		        session->driver.nmea2000.unit = 0;
+			session->driver.nmea2000.can_net = 0;
+			nmea2000_units[l1][l2] = NULL;
+		    }
+		}
+	    }
+	}
     }
 }
 
