@@ -3,6 +3,9 @@
  * Reference manuals are at
  * http://www.u-blox.com/en/download/documents-a-resources/u-blox-6-gps-modules-resources.html
  *
+ * updated for u-blox 8
+ * http://www.ublox.com/images/downloads/Product_Docs/u-bloxM8_ReceiverDescriptionProtocolSpec_%28UBX-13003221%29_Public.pdf
+ *
  * Week counters are not limited to 10 bits. It's unknown what
  * the firmware is doing to disambiguate them, if anything; it might just
  * be adding a fixed offset based on a hidden epoch value, in which case
@@ -21,9 +24,7 @@
 #include <assert.h>
 #include <string.h>
 #include <math.h>
-#ifndef S_SPLINT_S
 #include <unistd.h>
-#endif /* S_SPLINT_S */
 
 #include "gpsd.h"
 #if defined(UBLOX_ENABLE) && defined(BINARY_ENABLE)
@@ -58,20 +59,93 @@
 
 static gps_mask_t ubx_parse(struct gps_device_t *session, unsigned char *buf,
 			    size_t len);
-static gps_mask_t ubx_msg_nav_sol(struct gps_device_t *session,
-				  unsigned char *buf, size_t data_len);
 static gps_mask_t ubx_msg_nav_dop(struct gps_device_t *session,
 				  unsigned char *buf, size_t data_len);
-static gps_mask_t ubx_msg_nav_timegps(struct gps_device_t *session,
-				      unsigned char *buf, size_t data_len);
+static void ubx_msg_inf(struct gps_device_t *session, unsigned char *buf, size_t data_len);
+static gps_mask_t ubx_msg_nav_pvt(struct gps_device_t *session,
+				  unsigned char *buf, size_t data_len);
+static void ubx_msg_sbas(struct gps_device_t *session, unsigned char *buf);
+static gps_mask_t ubx_msg_nav_sol(struct gps_device_t *session,
+				  unsigned char *buf, size_t data_len);
 static gps_mask_t ubx_msg_nav_svinfo(struct gps_device_t *session,
 				     unsigned char *buf, size_t data_len);
-static void ubx_msg_sbas(struct gps_device_t *session, unsigned char *buf);
-static void ubx_msg_inf(struct gps_device_t *session, unsigned char *buf, size_t data_len);
+static gps_mask_t ubx_msg_nav_timegps(struct gps_device_t *session,
+				      unsigned char *buf, size_t data_len);
+static void ubx_msg_mon_ver(struct gps_device_t *session,
+				      unsigned char *buf, size_t data_len);
 #ifdef RECONFIGURE_ENABLE
 static void ubx_mode(struct gps_device_t *session, int mode);
 #endif /* RECONFIGURE_ENABLE */
 
+/**
+ * Receiver/Software Version
+ * UBX-MON-VER
+ *
+ * sadly more info than fits in session->swtype for now.
+ * so squish the data hard, max is maybe 100?
+ */
+static void
+ubx_msg_mon_ver(struct gps_device_t *session, unsigned char *buf,
+		size_t data_len)
+{
+    size_t n = 0;	/* extended info counter */
+    char obuf[128];     /* temp version string buffer */
+
+    if ( 44 > data_len ) {
+	/* incomplete message */
+        return;
+    }
+
+    /* save SW and HW Version as subtype */
+    (void)snprintf(obuf, sizeof(obuf),
+		   "SW %.30s,HW %.10s",
+		   (char *)&buf[UBX_MESSAGE_DATA_OFFSET + 0],
+		   (char *)&buf[UBX_MESSAGE_DATA_OFFSET + 30]);
+
+    /* get n number of Extended info strings.  what is max n? */
+    for ( n = 0; ; n++ ) {
+        size_t start_of_str = UBX_MESSAGE_DATA_OFFSET + 40 + (30 * n);
+
+        if ( (start_of_str + 2 ) > data_len ) {
+	    /* last one can be shorter than 30 */
+            /* no more data */
+            break;
+        }
+	(void)strlcat(obuf, ",", sizeof(obuf));
+	(void)strlcat(obuf, (char *)&buf[start_of_str], sizeof(obuf));
+    }
+    /* save what we can */
+    (void)strlcpy(session->subtype, obuf, sizeof(session->subtype));
+
+    /* output SW and HW Version at LOG_INFO */
+    gpsd_log(&session->context->errout, LOG_INF,
+	     "UBX_MON_VER: %.*s\n",
+             (int)sizeof(obuf), obuf);
+}
+
+/**
+ * Navigation Position Velocity Time  solution message
+ */
+static gps_mask_t
+ubx_msg_nav_pvt(struct gps_device_t *session, unsigned char *buf,
+		size_t data_len)
+{
+    unsigned int flags;
+    gps_mask_t mask = 0;
+
+    if (data_len != 92)
+	return 0;
+
+    flags = (unsigned int)getub(buf, 21);
+
+    /* TODO: finish decoding UBX_MON_PVT
+     * no need until depreacaed UBX_MON_SOL is dead
+     */
+    gpsd_log(&session->context->errout, LOG_DATA,
+	     "NAV-PVT: flags:%02x\n", flags);
+    return mask;
+}
+
 /**
  * Navigation solution message
  */
@@ -122,7 +196,7 @@ ubx_msg_nav_sol(struct gps_device_t *session, unsigned char *buf,
 
     session->newdata.eps = (double)(getles32(buf, 40) / 100.0);
     mask |= SPEEDERR_SET;
-    
+
     /* Better to have a single point of truth about DOPs */
     //session->gpsdata.dop.pdop = (double)(getleu16(buf, 44)/100.0);
     session->gpsdata.satellites_used = (int)getub(buf, 47);
@@ -247,7 +321,6 @@ ubx_msg_nav_svinfo(struct gps_device_t *session, unsigned char *buf,
 		 "runt svinfo (datalen=%zd)\n", data_len);
 	return 0;
     }
-    /*@ +charint @*/
     nchan = (unsigned int)getub(buf, 4);
     if (nchan > MAXCHANNELS) {
 	gpsd_log(&session->context->errout, LOG_WARN,
@@ -255,7 +328,6 @@ ubx_msg_nav_svinfo(struct gps_device_t *session, unsigned char *buf,
 		 MAXCHANNELS);
 	return 0;
     }
-    /*@ -charint @*/
     gpsd_zero_satellites(&session->gpsdata);
     nsv = 0;
     for (i = st = 0; i < nchan; i++) {
@@ -270,12 +342,10 @@ ubx_msg_nav_svinfo(struct gps_device_t *session, unsigned char *buf,
 	session->gpsdata.skyview[st].used = used;
 	if (session->gpsdata.skyview[st].PRN == 0)
 	    continue;
-	/*@ -predboolothers */
 	if (used || session->gpsdata.skyview[st].PRN == (short)session->driver.ubx.sbas_in_use) {
 	    nsv++;
 	    session->gpsdata.skyview[st].used = true;
 	}
-	/*@ +predboolothers */
 	st++;
     }
 
@@ -368,7 +438,6 @@ static void ubx_msg_inf(struct gps_device_t *session, unsigned char *buf, size_t
     return;
 }
 
-/*@ +charint @*/
 gps_mask_t ubx_parse(struct gps_device_t * session, unsigned char *buf,
 		     size_t len)
 {
@@ -401,11 +470,16 @@ gps_mask_t ubx_parse(struct gps_device_t * session, unsigned char *buf,
 	mask = ubx_msg_nav_dop(session, &buf[UBX_PREFIX_LEN], data_len);
 	break;
     case UBX_NAV_SOL:
+        /* UBX-NAV-SOL deprecated, use UBX-NAV-PVT instead */
 	gpsd_log(&session->context->errout, LOG_PROG, "UBX_NAV_SOL\n");
 	mask =
 	    ubx_msg_nav_sol(session, &buf[UBX_PREFIX_LEN],
 			    data_len) | (CLEAR_IS | REPORT_IS);
 	break;
+    case UBX_NAV_PVT:
+	gpsd_log(&session->context->errout, LOG_PROG, "UBX_NAV_PVT\n");
+	mask = ubx_msg_nav_pvt(session, &buf[UBX_PREFIX_LEN], data_len);
+        break;
     case UBX_NAV_POSUTM:
 	gpsd_log(&session->context->errout, LOG_DATA, "UBX_NAV_POSUTM\n");
 	break;
@@ -428,6 +502,16 @@ gps_mask_t ubx_parse(struct gps_device_t * session, unsigned char *buf,
     case UBX_NAV_SVINFO:
 	gpsd_log(&session->context->errout, LOG_PROG, "UBX_NAV_SVINFO\n");
 	mask = ubx_msg_nav_svinfo(session, &buf[UBX_PREFIX_LEN], data_len);
+
+	/* this is a hack to move some initialization until after we
+	 * get some u-blox message so we know the GPS is alive */
+	if ('\0' == session->subtype[0]) {
+	    /* one time only */
+	    (void)strlcpy(session->subtype, "Unknown", 8);
+	    /* request SW and HW Versions */
+	    (void)ubx_write(session, UBX_CLASS_MON, 0x04, NULL, 0);
+	}
+
 	break;
     case UBX_NAV_DGPS:
 	gpsd_log(&session->context->errout, LOG_DATA, "UBX_NAV_DGPS\n");
@@ -470,8 +554,7 @@ gps_mask_t ubx_parse(struct gps_device_t * session, unsigned char *buf,
 	break;
     case UBX_MON_VER:
 	gpsd_log(&session->context->errout, LOG_DATA, "UBX_MON_VER\n");
-	(void)strlcpy(session->subtype, 
-		      (char *)&buf[UBX_MESSAGE_DATA_OFFSET + 0], 30);
+	ubx_msg_mon_ver(session, buf, data_len);
 	break;
     case UBX_MON_EXCEPT:
 	gpsd_log(&session->context->errout, LOG_DATA, "UBX_MON_EXCEPT\n");
@@ -524,7 +607,7 @@ gps_mask_t ubx_parse(struct gps_device_t * session, unsigned char *buf,
 	break;
 
     case UBX_ACK_NAK:
-	gpsd_log(&session->context->errout, LOG_DATA,
+	gpsd_log(&session->context->errout, LOG_WARN,
 		 "UBX_ACK_NAK, class: %02x, id: %02x\n",
 		 buf[UBX_CLASS_OFFSET],
 		 buf[UBX_TYPE_OFFSET]);
@@ -541,11 +624,9 @@ gps_mask_t ubx_parse(struct gps_device_t * session, unsigned char *buf,
 		 "UBX: unknown packet id 0x%04hx (length %zd)\n",
 		 msgid, len);
     }
-
     return mask | ONLINE_SET;
 }
 
-/*@ -charint @*/
 
 static gps_mask_t parse_input(struct gps_device_t *session)
 {
@@ -569,7 +650,6 @@ bool ubx_write(struct gps_device_t * session,
     size_t i;
     bool ok;
 
-    /*@ -type @*/
     session->msgbuf[0] = 0xb5;
     session->msgbuf[1] = 0x62;
 
@@ -588,7 +668,6 @@ bool ubx_write(struct gps_device_t * session,
 	CK_A += session->msgbuf[i];
 	CK_B += CK_A;
     }
-    /*@ -nullderef @*/
     if (msg != NULL)
 	for (i = 0; i < data_len; i++) {
 	    CK_A += msg[i];
@@ -598,7 +677,6 @@ bool ubx_write(struct gps_device_t * session,
     session->msgbuf[6 + data_len] = CK_A;
     session->msgbuf[7 + data_len] = CK_B;
     session->msgbuflen = data_len + 8;
-    /*@ +type @*/
 
 
     gpsd_log(&session->context->errout, LOG_PROG,
@@ -607,7 +685,6 @@ bool ubx_write(struct gps_device_t * session,
 	     CK_A, CK_B);
     count = gpsd_write(session, session->msgbuf, session->msgbuflen);
     ok = (count == (ssize_t) session->msgbuflen);
-    /*@ +nullderef @*/
     return (ok);
 }
 
@@ -624,12 +701,8 @@ static ssize_t ubx_control_send(struct gps_device_t *session, char *msg,
 
 static void ubx_init_query(struct gps_device_t *session)
 {
-    unsigned char msg[32];
-
-    /*@ -type -compdef @*/
     /* MON_VER: query for version information */
-    (void)ubx_write(session, UBX_CLASS_MON, 0x04, msg, 0);
-    /*@ +type +compdef @*/
+    (void)ubx_write(session, UBX_CLASS_MON, 0x04, NULL, 0);
 }
 
 static void ubx_event_hook(struct gps_device_t *session, event_t event)
@@ -641,7 +714,6 @@ static void ubx_event_hook(struct gps_device_t *session, event_t event)
 
 	gpsd_log(&session->context->errout, LOG_DATA, "UBX configure\n");
 
-	/*@ -type @*/
 	msg[0] = 0x03;		/* SBAS mode enabled, accept testbed mode */
 	msg[1] = 0x07;		/* SBAS usage: range, differential corrections and integrity */
 	msg[2] = 0x03;		/* use the maximum search range: 3 channels */
@@ -651,10 +723,9 @@ static void ubx_event_hook(struct gps_device_t *session, event_t event)
 	msg[6] = 0x00;
 	msg[7] = 0x00;
 	(void)ubx_write(session, 0x06u, 0x16, msg, 8);
-	/*@ +type @*/
 
 #ifdef RECONFIGURE_ENABLE
-	/* 
+	/*
 	 * Turn off NMEA output, turn on UBX on this port.
 	 */
 	if (session->mode == O_OPTIMIZE) {
@@ -662,13 +733,11 @@ static void ubx_event_hook(struct gps_device_t *session, event_t event)
 	}
 #endif /* RECONFIGURE_ENABLE */
     } else if (event == event_deactivate) {
-	/*@ -type @*/
 	unsigned char msg[4] = {
 	    0x00, 0x00,		/* hotstart */
 	    0x01,		/* controlled software reset */
 	    0x00
 	};			/* reserved */
-	/*@ +type @*/
 
 	gpsd_log(&session->context->errout, LOG_DATA, "UBX revert\n");
 
@@ -678,17 +747,16 @@ static void ubx_event_hook(struct gps_device_t *session, event_t event)
 }
 
 #ifdef RECONFIGURE_ENABLE
-static void ubx_cfg_prt(struct gps_device_t *session, 
-			speed_t speed, const char parity, const int stopbits, 
+static void ubx_cfg_prt(struct gps_device_t *session,
+			speed_t speed, const char parity, const int stopbits,
 			const int mode)
-/* generare and send a configuration block */
+/* generate and send a configuration block */
 {
     unsigned long usart_mode = 0;
     unsigned char buf[UBX_CFG_LEN];
 
     memset(buf, '\0', UBX_CFG_LEN);
 
-    /*@ +ignoresigns +charint @*/
     /*
      * When this is called from gpsd, the initial probe for UBX should
      * have picked up the device's port number from the CFG_PRT response.
@@ -702,7 +770,7 @@ static void ubx_cfg_prt(struct gps_device_t *session,
      * What we'd like to do here is dispatch to USART1_ID or
      * USB_ID intelligently based on whether this is a USB or RS232
      * source.  Unfortunately the GR601-W screws that up by being
-     * a USB device with port_id 1.  So we bite the bullet and 
+     * a USB device with port_id 1.  So we bite the bullet and
      * default to port 1.
      *
      * Without further logic, this means gpsmon wouldn't be able to
@@ -783,11 +851,15 @@ static void ubx_cfg_prt(struct gps_device_t *session,
 	 * UBX after we've told it to start. Turning off the UBX protocol
 	 * mask, by itself, seems to be ineffective.
 	 */
+
 	unsigned char msg[3];
+
 	msg[0] = 0x01;		/* class */
 	msg[1] = 0x04;		/* msg id  = UBX_NAV_DOP */
 	msg[2] = 0x00;		/* rate */
 	(void)ubx_write(session, 0x06u, 0x01, msg, 3);
+
+        /* UBX-NAV-SOL deprecated, use UBX-NAV-PVT instead */
 	msg[0] = 0x01;		/* class */
 	msg[1] = 0x06;		/* msg id  = NAV-SOL */
 	msg[2] = 0x00;		/* rate */
@@ -847,15 +919,38 @@ static void ubx_cfg_prt(struct gps_device_t *session,
 	 * actually get UBX output; the sentence mix is initially empty.
 	 * Fix that...
 	 */
-	unsigned char msg[3];
+
+        /* FIXME: possibly sending too many messages without waiting
+         * for u-blox ACK, over running its input buffer.
+         *
+         * for example, the UBX_MON_VER fails here, but works in other
+         * contexts
+         */
+	unsigned char msg[3] = {0, 0, 0};
+        /* request SW and HW Versions */
+	(void)ubx_write(session, UBX_CLASS_MON, 0x04, msg, 0);
+
 	msg[0] = 0x01;		/* class */
 	msg[1] = 0x04;		/* msg id  = UBX_NAV_DOP */
 	msg[2] = 0x01;		/* rate */
 	(void)ubx_write(session, 0x06u, 0x01, msg, 3);
+
+        /* UBX-NAV-SOL deprecated, use UBX-NAV-PVT instead */
 	msg[0] = 0x01;		/* class */
 	msg[1] = 0x06;		/* msg id  = NAV-SOL */
 	msg[2] = 0x01;		/* rate */
 	(void)ubx_write(session, 0x06u, 0x01, msg, 3);
+
+#ifdef __UNUSED__
+        /* leave here for testing.  No need to enable until gpsd
+         * can decode UBX-MON-VER */
+	msg[0] = 0x01;		/* class */
+	msg[1] = 0x07;		/* msg id  = NAV-PVT */
+	msg[2] = 0x01;		/* rate */
+	(void)ubx_write(session, 0x06u, 0x01, msg, 3);
+#endif /* __UNUSED __ */
+
+
 	msg[0] = 0x01;		/* class */
 	msg[1] = 0x20;		/* msg id  = UBX_NAV_TIMEGPS */
 	msg[2] = 0x01;		/* rate */
@@ -869,6 +964,7 @@ static void ubx_cfg_prt(struct gps_device_t *session,
 	msg[2] = 0x0a;		/* rate */
 	(void)ubx_write(session, 0x06u, 0x01, msg, 3);
 
+
 #ifdef __UNUSED__
 	/*
 	 * In theory this should turn off NMEA reporting even if
@@ -913,15 +1009,14 @@ static void ubx_cfg_prt(struct gps_device_t *session,
 
 	buf[outProtoMask] &= ~NMEA_PROTOCOL_MASK;
 	buf[outProtoMask] |= UBX_PROTOCOL_MASK;
-    }    
-    /*@ -ignoresigns -charint @*/
+    }
 
     (void)ubx_write(session, 0x06u, 0x00, buf, sizeof(buf));
 }
 
 static void ubx_mode(struct gps_device_t *session, int mode)
 {
-    ubx_cfg_prt(session, 
+    ubx_cfg_prt(session,
 		gpsd_get_speed(session),
 		gpsd_get_parity(session),
 		gpsd_get_stopbits(session),
@@ -931,7 +1026,7 @@ static void ubx_mode(struct gps_device_t *session, int mode)
 static bool ubx_speed(struct gps_device_t *session,
 		      speed_t speed, char parity, int stopbits)
 {
-    ubx_cfg_prt(session, 
+    ubx_cfg_prt(session,
 		speed,
 		parity,
 		stopbits,
@@ -943,13 +1038,11 @@ static bool ubx_rate(struct gps_device_t *session, double cycletime)
 /* change the sample rate of the GPS */
 {
     unsigned short s;
-    /*@ -type @*/
     unsigned char msg[6] = {
 	0x00, 0x00,		/* U2: Measurement rate (ms) */
 	0x00, 0x01,		/* U2: Navigation rate (cycles) */
 	0x00, 0x00,		/* U2: Alignment to reference time: 0 = UTC, !0 = GPS */
     };
-    /*@ +type @*/
 
     /* clamp to cycle times that i know work on my receiver */
     if (cycletime > 1000.0)
@@ -988,7 +1081,7 @@ const struct gps_type_t driver_ubx = {
     .min_cycle        = 0.25,           /* Maximum 4Hz sample rate */
 #endif /* RECONFIGURE_ENABLE */
 #ifdef CONTROLSEND_ENABLE
-    .control_send     = ubx_control_send,	/* no control sender yet */
+    .control_send     = ubx_control_send,/* how to send a control string */
 #endif /* CONTROLSEND_ENABLE */
 #ifdef TIMEHINT_ENABLE
     .time_offset     = NULL,		/* no method for NTP fudge factor */
