@@ -9,9 +9,7 @@
 #include <stdarg.h>
 #include <assert.h>
 #include <ctype.h>
-#ifndef S_SPLINT_S
 #include <unistd.h>
-#endif /* S_SPLINT_S */
 
 #include "gpsd.h"
 #include "bits.h"		/* for getbeu16(), to extract big-endian words */
@@ -507,34 +505,19 @@ const struct gps_type_t driver_fv18 = {
  * Based on http://www.tecsys.de/fileadmin/user_upload/pdf/gh79_1an_intant.pdf
  */
 
-static void gpsclock_event_hook(struct gps_device_t *session, event_t event)
-{
-    if (session->context->readonly)
-	return;
-    /*
-     * Michael St. Laurent <mikes@hartwellcorp.com> reports that you have to
-     * ignore the trailing PPS edge when extracting time from this chip.
-     */
-    if (event == event_identified || event == event_reactivate) {
-	gpsd_log(&session->context->errout, LOG_INF,
-		 "PPS trailing edge will be ignored\n");
-	session->nmea.ignore_trailing_edge = true;
-    }
-}
-
 /* *INDENT-OFF* */
 const struct gps_type_t driver_gpsclock = {
     .type_name      = "Furuno Electric GH-79L4",	/* full name of type */
     .packet_type    = NMEA_PACKET,	/* associated lexer packet type */
     .flags	    = DRIVER_STICKY,	/* remember this */
-    .trigger	    = "$PFEC,GPssd",	/* GPSclock should return this */
+    .trigger	    = "$PFEC,GPssd",	/* GPSClock should return this */
     .channels       = 12,		/* not used by this driver */
     .probe_detect   = NULL,		/* no probe */
     .get_packet     = generic_get,	/* how to get a packet */
     .parse_packet   = generic_parse_input,	/* how to interpret a packet */
     .rtcm_writer    = gpsd_write,	/* write RTCM data straight */
     .init_query     = NULL,		/* non-perturbing initial query */
-    .event_hook     = gpsclock_event_hook,	/* lifetime event handler */
+    .event_hook     = NULL,		/* no lifetime event handler */
 #ifdef RECONFIGURE_ENABLE
     .speed_switcher = NULL,		/* no speed switcher */
     .mode_switcher  = NULL,		/* no mode switcher */
@@ -629,7 +612,6 @@ static void earthmate_event_hook(struct gps_device_t *session, event_t event)
     }
 }
 
-/*@ -redef @*/
 /* *INDENT-OFF* */
 static const struct gps_type_t driver_earthmate = {
     .type_name     = "Pre-2003 Delorme EarthMate",
@@ -656,7 +638,6 @@ static const struct gps_type_t driver_earthmate = {
     .time_offset     = NULL,		/* no method for NTP fudge factor */
 #endif /* TIMEHINT_ENABLE */
 };
-/*@ -redef @*/
 /* *INDENT-ON* */
 #endif /* EARTHMATE_ENABLE */
 
@@ -686,7 +667,7 @@ static ssize_t tnt_control_send(struct gps_device_t *session,
 
     if (*p == '@') {
 	p++;
-    } 
+    }
 #ifdef __UNUSED__
     else {
 	gpsd_log(&session->context->errout, LOG_ERROR,
@@ -799,7 +780,7 @@ const struct gps_type_t driver_trueNorth = {
  *
  **************************************************************************/
 
-static int oceanserver_send(struct gpsd_errout_t *errout, 
+static int oceanserver_send(struct gpsd_errout_t *errout,
 			    const int fd, const char *fmt, ...)
 {
     int status;
@@ -1000,7 +981,7 @@ static gps_mask_t rtcm104v3_analyze(struct gps_device_t *session)
 
     gpsd_log(&session->context->errout, LOG_RAW, "RTCM 3.x packet %d\n", type);
     rtcm3_unpack(session->context,
-		 &session->gpsdata.rtcm3, 
+		 &session->gpsdata.rtcm3,
 		 (char *)session->lexer.outbuffer);
     session->cycle_end_reliable = true;
     return RTCM3_SET;
@@ -1082,7 +1063,7 @@ static const struct gps_type_t driver_garmintxt = {
  * The Trimble Condor appears to be an MTK3329.  It behaves as an MTK3301
  * and positively acknowledges all 3301 sentences as valid. It ignores $PMTK
  * sentence fields that are not implemented in the Trimble Condor. It does
- * not have power0save mode abd ignores $PMTK320.  For $PMTK314 it silently
+ * not have power-save mode and ignores $PMTK320.  For $PMTK314 it silently
  * ignores periodic enabling of messages that aren't supported.
  *
  **************************************************************************/
@@ -1112,12 +1093,16 @@ static void mtk3301_event_hook(struct gps_device_t *session, event_t event)
 	return;
     if (event == event_triggermatch) {
 	(void)nmea_send(session, "$PMTK320,0");	/* power save off */
-	(void)nmea_send(session, "$PMTK300,1000,0,0,0.0,0.0");	/* Fix interval */
+	(void)nmea_send(session, "$PMTK300,1000,0,0,0.0,0.0");/* Fix interval */
 	(void)nmea_send(session,
 			"$PMTK314,0,1,0,1,1,5,1,1,0,0,0,0,0,0,0,0,0,1,0");
 	(void)nmea_send(session, "$PMTK301,2");	/* DGPS is WAAS */
 	(void)nmea_send(session, "$PMTK313,1");	/* SBAS enable */
-	(void)nmea_send(session, "$PMTK424");	/* Query PPS pulse width */
+
+        /* PMTK_API_Q_OUTPUT_CTL - Query PPS pulse width - Trimble only?
+         * http://trl.trimble.com/docushare/dsweb/Get/Document-482603/CONDOR_UG_2C_75263-00.pdf *
+         * badly documented */
+	 (void)nmea_send(session, "$PMTK424");	
     }
 }
 
@@ -1126,7 +1111,7 @@ static bool mtk3301_rate_switcher(struct gps_device_t *session, double rate)
 {
     char buf[78];
 
-    /*@i1@*/ unsigned int milliseconds = 1000 * rate;
+    unsigned int milliseconds = (unsigned int)(1000 * rate);
     if (rate > 1)
 	milliseconds = 1000;
     else if (rate < 0.2)
@@ -1174,7 +1159,6 @@ const struct gps_type_t driver_mtk3301 = {
  *
  **************************************************************************/
 
-/*@ -fixedformalarray -usedef -branchstate @*/
 static bool aivdm_decode(const char *buf, size_t buflen,
 		  struct gps_device_t *session,
 		  struct ais_t *ais,
@@ -1258,13 +1242,11 @@ static bool aivdm_decode(const char *buf, size_t buflen,
 		     "ignoring bogus AIS channel '12'.\n");
 	    return false;
 	}
-	/*@fallthrough@*/
     case 'A':
 	ais_context = &session->driver.aivdm.context[0];
 	session->driver.aivdm.ais_channel ='A';
 	break;
     case '2':
-	/*@fallthrough@*/
     case 'B':
 	ais_context = &session->driver.aivdm.context[1];
 	session->driver.aivdm.ais_channel ='B';
@@ -1306,7 +1288,6 @@ static bool aivdm_decode(const char *buf, size_t buflen,
     }
 
     /* wacky 6-bit encoding, shades of FIELDATA */
-    /*@ +charint @*/
     for (cp = data; cp < data + strlen((char *)data); cp++) {
 	unsigned char ch;
 	ch = *cp;
@@ -1317,7 +1298,6 @@ static bool aivdm_decode(const char *buf, size_t buflen,
 	gpsd_log(&session->context->errout, LOG_RAW,
 		 "%c: %s\n", *cp, sixbits[ch]);
 #endif /* __UNUSED_DEBUG__ */
-	/*@ -shiftnegative @*/
 	for (i = 5; i >= 0; i--) {
 	    if ((ch >> i) & 0x01) {
 		ais_context->bits[ais_context->bitlen / 8] |=
@@ -1330,11 +1310,9 @@ static bool aivdm_decode(const char *buf, size_t buflen,
 		return false;
 	    }
 	}
-	/*@ +shiftnegative @*/
     }
     if (isdigit(pad))
 	ais_context->bitlen -= (pad - '0');	/* ASCII assumption */
-    /*@ -charint @*/
 
     /* time to pass buffered-up data to where it's actually processed? */
     if (ifrag == nfrags) {
@@ -1362,14 +1340,13 @@ static bool aivdm_decode(const char *buf, size_t buflen,
     ais_context->decoded_frags++;
     return false;
 }
-/*@ +fixedformalarray +usedef +branchstate @*/
 
 static gps_mask_t aivdm_analyze(struct gps_device_t *session)
 {
     if (session->lexer.type == AIVDM_PACKET) {
 	if (aivdm_decode
 	    ((char *)session->lexer.outbuffer, session->lexer.outbuflen,
-	     session, &session->gpsdata.ais, 
+	     session, &session->gpsdata.ais,
 	     session->context->errout.debug)) {
 	    return ONLINE_SET | AIS_SET;
 	} else
@@ -1430,9 +1407,7 @@ static void path_rewrite(struct gps_device_t *session, char *prefix)
      */
     char *prefloc;
 
-#ifdef S_SPLINT_S
     assert(prefix != NULL && session->lexer.outbuffer != NULL);
-#endif /* S_SPLINT_S */
 
     /* possibly the rewrite has been done already, this comw up in gpsmon */
     if (strstr((char *)session->lexer.outbuffer, session->gpsdata.dev.path) != NULL)
@@ -1466,7 +1441,6 @@ static gps_mask_t json_pass_packet(struct gps_device_t *session)
 
     if (strstr(session->gpsdata.dev.path, ":/") != NULL && strstr(session->gpsdata.dev.path, "localhost") == NULL)
     {
-	/*@-nullpass@*/ /* required only because splint is buggy */
 	/* devices and paths need to be edited */
 	if (strstr((char *)session->lexer.outbuffer, "DEVICE") != NULL)
 	    path_rewrite(session, "\"path\":\"");
@@ -1492,7 +1466,6 @@ static gps_mask_t json_pass_packet(struct gps_device_t *session)
     gpsd_log(&session->context->errout, LOG_PROG,
 	     "JSON, passing through %s\n",
 	     (char *)session->lexer.outbuffer);
-    /*@-nullpass@*/
     return PASSTHROUGH_IS;
 }
 
@@ -1526,6 +1499,38 @@ const struct gps_type_t driver_json_passthrough = {
 
 #endif /* PASSTHROUGH_ENABLE */
 
+#if defined(PPS_ENABLE)
+/* *INDENT-OFF* */
+const struct gps_type_t driver_pps = {
+    .type_name      = "PPS",		/* full name of type */
+    .packet_type    = BAD_PACKET,	/* associated lexer packet type */
+    .flags	    = DRIVER_NOFLAGS,	/* don't remember this */
+    .trigger	    = NULL,		/* it's the default */
+    .channels       = 0,		/* not used */
+    .probe_detect   = NULL,		/* no probe */
+    .get_packet     = NULL,		/* use generic packet getter */
+    .parse_packet   = NULL,		/* how to interpret a packet */
+    .rtcm_writer    = NULL,		/* write RTCM data straight */
+    .init_query     = NULL,		/* non-perturbing initial query */
+    .event_hook     = NULL,		/* lifetime event handler */
+#ifdef RECONFIGURE_ENABLE
+    .speed_switcher = NULL,		/* no speed switcher */
+    .mode_switcher  = NULL,		/* no mode switcher */
+    .rate_switcher  = NULL,		/* no sample-rate switcher */
+    .min_cycle      = 1,		/* not relevant, no rate switch */
+#endif /* RECONFIGURE_ENABLE */
+#ifdef CONTROLSEND_ENABLE
+    .control_send   = NULL,		/* how to send control strings */
+#endif /* CONTROLSEND_ENABLE */
+#ifdef TIMEHINT_ENABLE
+    .time_offset     = NULL,		/* no method for NTP fudge factor */
+#endif /* TIMEHINT_ENABLE */
+};
+/* *INDENT-ON* */
+
+#endif /* PPS_ENABLE */
+
+
 extern const struct gps_type_t driver_evermore;
 extern const struct gps_type_t driver_garmin_ser_binary;
 extern const struct gps_type_t driver_garmin_usb_binary;
@@ -1540,7 +1545,6 @@ extern const struct gps_type_t driver_tsip;
 extern const struct gps_type_t driver_ubx;
 extern const struct gps_type_t driver_zodiac;
 
-/*@ -nullassign @*/
 /* the point of this rigamarole is to not have to export a table size */
 static const struct gps_type_t *gpsd_driver_array[] = {
     &driver_unknown,
@@ -1634,9 +1638,11 @@ static const struct gps_type_t *gpsd_driver_array[] = {
 #ifdef PASSTHROUGH_ENABLE
     &driver_json_passthrough,
 #endif /* PASSTHROUGH_ENABLE */
+#if defined(PPS_ENABLE)
+    &driver_pps,
+#endif /* PPS_ENABLE */
 
     NULL,
 };
 
-/*@ +nullassign @*/
 const struct gps_type_t **gpsd_drivers = &gpsd_driver_array[0];
