@@ -1,7 +1,7 @@
 /*
  * gps2udp
  *
- * Dump NMEA to UDP socket for AIShub 
+ * Dump NMEA to UDP socket for AIShub
  *      gps2udp -u data.aishub.net:1234
  *
  * Author: Fulup Ar Foll (directly inspired from gpspipe.c)
@@ -28,23 +28,17 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/select.h>
-
-#ifndef S_SPLINT_S
 #include <unistd.h>
-#endif /* S_SPLINT_S */
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
+#include <netdb.h>
 
 #include "gpsd.h"
 #include "gpsdclient.h"
 #include "revision.h"
 #include "strfuncs.h"
 
-#ifndef S_SPLINT_S
-#include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-#include <netdb.h>
-#endif /* S_SPLINT_S */
-
 #define MAX_TIME_LEN 80
 #define MAX_GPSD_RETRY 10
 
@@ -62,26 +56,24 @@ static unsigned int flags;
 static int debug = 0;
 static bool aisonly = false;
 
-/*@-statictrans@*/
-/*@observer@*/static char* time2string(void)  
+static char* time2string(void)
 /* return local time hh:mm:ss */
 {
    static char buffer[MAX_TIME_LEN];
    time_t curtime;
    struct tm *loctime;
-     
+
    /* Get the current time. */
    curtime = time (NULL);
-     
+
    /* Convert it to local time representation. */
    loctime = localtime (&curtime);
-     
+
    /* Print it out in a nice format. */
    (void)strftime (buffer, sizeof(buffer), "%H:%M:%S", loctime);
-     
+
    return (buffer);
 }
-/*@+statictrans@*/
 
 static int send_udp (char *nmeastring, size_t ind)
 {
@@ -116,7 +108,6 @@ static int send_udp (char *nmeastring, size_t ind)
     }
 
     /* send message on udp channel */
-    /*@-type@*/
     for (channel=0; channel < udpchannel; channel ++) {
 	ssize_t status = sendto(sock[channel],
 				buffer,
@@ -129,7 +120,6 @@ static int send_udp (char *nmeastring, size_t ind)
 	    return -1;
 	}
     }
-    /*@=type@*/
     return 0;
 }
 
@@ -148,10 +138,8 @@ static int open_udp(char **hostport)
        struct hostent *hp;
 
        /* parse argument */
-       /*@-unrecog@*/
        hostname = strsep(&hostport[channel], ":");
        portname = strsep(&hostport[channel], ":");
-       /*@=unrecog@*/
        if ((hostname == NULL) || (portname == NULL)) {
 	   (void)fprintf(stderr, "gps2udp: syntax is [-u hostname:port]\n");
 	   return (-1);
@@ -159,12 +147,10 @@ static int open_udp(char **hostport)
 
        errno = 0;
        portnum = (int)strtol(portname, &endptr, 10);
-       /*@+charint@*/
        if (1 > portnum || 65535 < portnum || '\0' != *endptr || 0 != errno) {
 	   (void)fprintf(stderr, "gps2udp: syntax is [-u hostname:port] [%s] is not a valid port number\n",portname);
 	   return (-1);
        }
-       /*@-charint@*/
 
        sock[channel]= socket(AF_INET, SOCK_DGRAM, 0);
        if (sock[channel] < 0) {
@@ -189,14 +175,14 @@ static void usage(void)
 {
     (void)fprintf(stderr,
 		  "Usage: gps2udp [OPTIONS] [server[:port[:device]]]\n\n"
-		  "-h Show this help.\n" 
+		  "-h Show this help.\n"
                   "-u Send UDP NMEA/JASON feed to host:port [multiple -u host:port accepted\n"
 		  "-n Feed NMEA.\n"
 		  "-j Feed Jason.\n"
 		  "-a Select !AISDM message only.\n"
 		  "-c [count] exit after count packets.\n"
-		  "-b Run in background as a daemon.\n" 
-		  "-d [0-2] 1 display sent packets, 2 ignored packets.\n" 
+		  "-b Run in background as a daemon.\n"
+		  "-d [0-2] 1 display sent packets, 2 ignored packets.\n"
 		  "-v Print version and exit.\n\n"
                   "example: gps2udp -a -n -c 2 -d 1 -u data.aishub.net:2222 fridu.net\n"
 		  );
@@ -232,13 +218,12 @@ static void connect2gpsd(bool restart)
     }
     /* select the right set of gps data */
     (void)gps_stream(&gpsdata, flags, gpsd_source.device);
-    
+
 }
 
-/*@+voidabstract@*/
 static ssize_t read_gpsd(char *message, size_t len)
 /* get data from gpsd */
-{   
+{
     struct timeval tv;
     fd_set fds,master;
     int ind;
@@ -255,9 +240,9 @@ static ssize_t read_gpsd(char *message, size_t len)
         /* prepare for a blocking read with a 10s timeout */
         tv.tv_sec =  10;
         tv.tv_usec = 0;
-        memcpy(&fds, &master, sizeof(fd_set));
+        fds = master;
         result = select(gpsdata.gps_fd+1, &fds, NULL, NULL, &tv);
-      
+
         switch (result)
 	{
         case 1: /* we have data waiting, let's process them */
@@ -267,7 +252,7 @@ static ssize_t read_gpsd(char *message, size_t len)
 	    if (result != 1) {
 		connect2gpsd (true);
 	    }
-            
+
 	    if ((c == '\n') || (c == '\r')){
 		message[ind]='\0';
 
@@ -289,7 +274,7 @@ static ssize_t read_gpsd(char *message, size_t len)
 			return(0);
 		    }
 		}
-                     
+
 		return ((ssize_t)ind+1);
 	    } else {
 		message[ind]= c;
@@ -305,10 +290,8 @@ static ssize_t read_gpsd(char *message, size_t len)
 		connect2gpsd(true);
 		retry = 0;
 	    }
-	    /*@-sefparams@*/
 	    if (debug > 0)
 		ignore_return(write (1, ".", 1));
-	    /*@+sefparams@*/
 	    break;
 
         default:	/* we lost connection with gpsd */
@@ -320,7 +303,6 @@ static ssize_t read_gpsd(char *message, size_t len)
     (void)fprintf (stderr,"\n gps2udp: message too big [%s]\n", message);
     return(-1);
 }
-/*@=voidabstract@*/
 
 static unsigned char AISto6bit(unsigned char c)
 /* 6 bits decoding of AIS payload */
@@ -363,7 +345,6 @@ static unsigned int AISGetInt(unsigned char *bitbytes, unsigned int sp, unsigned
     return acc;
 }
 
-/*@-compdef -usedef@*/
 int main(int argc, char **argv)
 {
     bool daemonize = false;
@@ -403,7 +384,7 @@ int main(int argc, char **argv)
 	    break;
         case 'u':
             if (udpchannel >= MAX_UDP_DEST) {
-		(void)fprintf(stderr, 
+		(void)fprintf(stderr,
 			      "gps2udp: too many UDP destinations (max=%d)\n",
 			      MAX_UDP_DEST);
             } else {
@@ -440,15 +421,13 @@ int main(int argc, char **argv)
     }
 
     /* Daemonize if the user requested it. */
-    /*@-unrecog@*/
     if (daemonize) {
 	if (daemon(0, 0) != 0) {
-	    (void)fprintf(stderr, 
+	    (void)fprintf(stderr,
 			  "gps2udp: demonization failed: %s\n",
 			  strerror(errno));
         }
     }
-    /*@=unrecog@*/
 
     /* infinite loop to get data from gpsd and push them to aggregators */
     for (;;)
@@ -457,7 +436,7 @@ int main(int argc, char **argv)
 	ssize_t  len;
 
 	len = read_gpsd(buffer, sizeof(buffer));
- 
+
 	/* ignore empty message */
 	if (len > 3)
 	{
@@ -487,10 +466,10 @@ int main(int argc, char **argv)
 			bitstrings[i] = AISto6bit(info[5][i]);
 		    }
 
-		    mmsi = AISGetInt(bitstrings, 9, 30); 
+		    mmsi = AISGetInt(bitstrings, 9, 30);
 		    (void)fprintf(stdout," MMSI=%9u", mmsi);
 
-		} 
+		}
 		fprintf(stdout,"\n");
 	    }
 
@@ -502,19 +481,17 @@ int main(int argc, char **argv)
 	    if (count >= 0) {
 		if (count-- == 0) {
 		    /* completed count */
-		    (void)fprintf(stderr, 
+		    (void)fprintf(stderr,
 				  "gpsd2udp: normal exit after counted packets\n");
 		    exit (0);
 		}
-	    }  // end count  
+	    }  // end count
         } // end len > 3
     } // end for (;;)
- 
+
     // This is an infinite loop, should never be here
-    /*@-unreachable@*/
     fprintf (stderr, "gpsd2udp ERROR abnormal exit\n");
     exit (-1);
 }
-/*@=compdef =usedef@*/
 
 /* end */
