@@ -56,7 +56,7 @@ class GPSDictionary(ConfigParser.RawConfigParser):
                     raise ConfigParser.Error("%s has invalid vendor" % section)
 
     def HTMLDump(self, ofp):
-        thead = """<table border='1' style='font-size:small;background-color:#CCCCCC'>
+        thead = """<table style='border:1px solid gray;font-size:small;background-color:#CCCCCC'>
 <caption>Listing %s devices from %s vendors</caption>
 <tr>
 <th>Name</th>
@@ -69,8 +69,8 @@ class GPSDictionary(ConfigParser.RawConfigParser):
 <th style='width:50%%'>Notes</th>
 </tr>
 """
-        vhead1 = "<tr><td style='text-align:center;' colspan='7'><a href='%s'>%s</a></td></tr>\n"
-        vhead2 = "<tr><td style='text-align:center;' colspan='7'><a href='%s'>%s</a><br><p>%s</p></td></tr>\n"
+        vhead1 = "<tr><td style='text-align:center;' colspan='8'><a href='%s'>%s</a></td></tr>\n"
+        vhead2 = "<tr><td style='text-align:center;' colspan='8'><a href='%s'>%s</a><br><p>%s</p></td></tr>\n"
         hotpluggables = ("pl2303", "CP2101")
         ofp.write(thead % (len(self.devices), len(self.vendors)))
         for vendor in self.vendors:
@@ -86,21 +86,21 @@ class GPSDictionary(ConfigParser.RawConfigParser):
             for dev in relevant:
                 rowcolor = "white"
                 if self.get(dev, "packaging") == "OEM module":
-                    rowcolor = "LimeGreen"
+                    rowcolor = "#32CD32"
                 elif self.get(dev, "packaging") == "chipset":
-                    rowcolor = "LightYellow"
+                    rowcolor = "#FFFFE0"
                 elif self.get(dev, "packaging") == "handset":
-                    rowcolor = "Cyan"
+                    rowcolor = "#00FFFF"
                 elif self.get(dev, "packaging") == "hansdfree":
-                    rowcolor = "DarkCyan"
+                    rowcolor = "#008B8B"
 
-                ofp.write("<tr style='background-color:%s'>\n" % rowcolor)
+                ofp.write("<tr itemscope itemtype='http://schema.org/Product' style='background-color:%s'>\n" % rowcolor)
                 namefield = dev
                 if self.has_option(dev, "techdoc"):
                     namefield = "<a href='%s'>%s</a>" % (self.get(dev, "techdoc"), dev)
                 if self.has_option(dev, "discontinued") and self.getboolean(dev, "discontinued"):
                     namefield = namefield + "&nbsp;<img title='Device discontinued' src='discontinued.png' alt='Discontinued icon'>"
-                ofp.write("<td>%s</td>\n" % namefield)
+                ofp.write("<td itemprop='name'>%s</td>\n" % namefield)
                 ofp.write("<td>%s</td>\n" % self.get(dev, "packaging"))
                 engine = self.get(dev, "engine")
                 if self.has_option(engine, "techdoc"):
@@ -132,7 +132,7 @@ class GPSDictionary(ConfigParser.RawConfigParser):
                 elif self.get(dev, "rating") == "broken":
                     testfield += "<img title='Device is broken' src='bomb.png' alt='Bomb icon'>"
                 if self.has_option(dev, "usbchip") and self.get(dev, "usbchip") in hotpluggables:
-                    testfield += "<img src='hotplug.png' alt='Hotplug icon'>"
+                    testfield += "<img title='udev hotplug' src='hotplug.png' alt='Hotplug icon'>"
                 ofp.write("<td>%s</td>\n" % testfield)
                 nmea = "&nbsp;"
                 if self.has_option(dev, "nmea"):
@@ -156,7 +156,7 @@ class GPSDictionary(ConfigParser.RawConfigParser):
                     notes = ""
                 if self.has_option(dev, "submitter"):
                     notes += " Reported by %s." % self.get(dev, "submitter").replace("@", "&#x40;").replace("<", "&lt;").replace(">", "&gt;")
-                ofp.write("<td>%s</td>\n" % notes)
+                ofp.write("<td itemscope itemtype='http://schema.org/description'>%s</td>\n" % notes)
                 ofp.write("</tr>\n")
         ofp.write("</table>\n")
 
