@@ -15,9 +15,7 @@
 #include <time.h>
 #include <sys/time.h>
 #include <sys/select.h>
-#ifndef S_SPLINT_S
 #include <unistd.h>
-#endif /* S_SPLINT_S */
 
 #include "gpsd.h"
 #include "revision.h"
@@ -55,13 +53,13 @@ static void settle(struct gps_device_t *session)
 #endif /* defined(RECONFIGURE_ENABLE) || defined(CONTROLSEND_ENABLE) */
 
 /*
- * Allows any response other than ERROR.  Use it for queries where a 
- * failure return (due to, for example, a missing driver method) is 
- * immediate, but successful responses have unpredictable lag.  
+ * Allows any response other than ERROR.  Use it for queries where a
+ * failure return (due to, for example, a missing driver method) is
+ * immediate, but successful responses have unpredictable lag.
  */
 #define NON_ERROR	0	/* must be distinct from any gps_mask_t value */
 
-static bool gps_query(/*@out@*/struct gps_data_t *gpsdata,
+static bool gps_query(struct gps_data_t *gpsdata,
 		       gps_mask_t expect,
 		       const int timeout,
 		       const char *fmt, ... )
@@ -86,12 +84,10 @@ static bool gps_query(/*@out@*/struct gps_data_t *gpsdata,
     va_end(ap);
     if (buf[strlen(buf)-1] != '\n')
 	(void)strlcat(buf, "\n", sizeof(buf));
-    /*@-usedef@*/
     if (write(gpsdata->gps_fd, buf, strlen(buf)) <= 0) {
 	gpsd_log(&context.errout, LOG_ERROR, "gps_query(), write failed\n");
 	return false;
     }
-    /*@+usedef@*/
     gpsd_log(&context.errout, LOG_PROG, "gps_query(), wrote, %s\n", buf);
 
     FD_ZERO(&rfds);
@@ -101,7 +97,6 @@ static bool gps_query(/*@out@*/struct gps_data_t *gpsdata,
 
 	gpsd_log(&context.errout, LOG_PROG, "waiting...\n");
 
-	/*@ -usedef -type -nullpass -compdef @*/
 	tv.tv_sec = 2;
 	tv.tv_nsec = 0;
 	if (pselect(gpsdata->gps_fd + 1, &rfds, NULL, NULL, &tv, &oldset) == -1) {
@@ -110,7 +105,6 @@ static bool gps_query(/*@out@*/struct gps_data_t *gpsdata,
 	    gpsd_log(&context.errout, LOG_ERROR, "select %s\n", strerror(errno));
 	    exit(EXIT_FAILURE);
 	}
-	/*@ +usedef +type +nullpass +compdef @*/
 
 	gpsd_log(&context.errout, LOG_PROG, "reading...\n");
 
@@ -120,7 +114,6 @@ static bool gps_query(/*@out@*/struct gps_data_t *gpsdata,
 	    return false;
 	}
 
-	/*@ +ignorequals @*/
 	if ((expect == NON_ERROR) || (expect & gpsdata->set) != 0)
 	    return true;
 	else if (timeout > 0 && (time(NULL) - starttime > timeout)) {
@@ -129,7 +122,6 @@ static bool gps_query(/*@out@*/struct gps_data_t *gpsdata,
 		     timeout);
 	    return false;
 	}
-	/*@ -ignorequals @*/
     }
 
     return false;
@@ -146,7 +138,7 @@ static void onsig(int sig)
     }
 }
 
-static char /*@observer@*/ *gpsd_id( /*@in@ */ struct gps_device_t *session)
+static char *gpsd_id(struct gps_device_t *session)
 /* full ID of the device for reports, including subtype */
 {
     static char buf[128];
@@ -178,7 +170,6 @@ static void ctlhook(struct gps_device_t *device UNUSED, gps_mask_t changed UNUSE
     }
 }
 
-/*@-mustfreeonly -observertrans -statictrans@*/
 int main(int argc, char **argv)
 {
     int option, status;
@@ -286,7 +277,6 @@ int main(int argc, char **argv)
 	    break;
 	case 'R':		/* remove the SHM export segment */
 #ifdef SHM_EXPORT_ENABLE
-	    /*@-nullpass@*/
 	    status = shmget(getenv("GPSD_SHM_KEY") ? (key_t)strtol(getenv("GPSD_SHM_KEY"), NULL, 0) : (key_t)GPSD_SHM_KEY, 0, 0);
 	    if (status == -1) {
 		gpsd_log(&context.errout, LOG_WARN,
@@ -301,7 +291,6 @@ int main(int argc, char **argv)
 		    exit(1);
 		}
 	    }
-	    /*@+nullpass@*/
 	    exit(0);
 #endif /* SHM_EXPORT_ENABLE */
 	case 'T':		/* set the timeout on packet recognition */
@@ -360,7 +349,6 @@ int main(int argc, char **argv)
     (void) signal(SIGTERM, onsig);
     (void) signal(SIGQUIT, onsig);
 
-    /*@-nullpass@*/ /* someday, add null annotation to the gpsopen() params */
     if (!lowlevel) {
 	/* Try to open the stream to gpsd. */
 	if (gps_open(NULL, NULL, &gpsdata) != 0) {
@@ -370,7 +358,6 @@ int main(int argc, char **argv)
 	    lowlevel = true;
 	}
     }
-    /*@-nullpass@*/
 
     if (!lowlevel) {
 	int i, devcount;
@@ -413,9 +400,7 @@ int main(int argc, char **argv)
 	    exit(EXIT_FAILURE);
 	devicelist_entry_matches:;
 	}
-	(void)memcpy(&gpsdata.dev,
-		     &gpsdata.devices.list[i],
-		     sizeof(struct devconfig_t));
+	gpsdata.dev = gpsdata.devices.list[i];
 	devcount = gpsdata.devices.ndevices;
 
 	/* if the device has not identified, watch it until it does so */
@@ -459,7 +444,7 @@ int main(int argc, char **argv)
 
 	/* if no control operation was specified, just ID the device */
 	if (speed==NULL && rate == NULL && !to_nmea && !to_binary && !reset) {
-	    (void)printf("%s identified as a %s", 
+	    (void)printf("%s identified as a %s",
 			 gpsdata.dev.path, gpsdata.dev.driver);
 	    if (gpsdata.dev.subtype[0] != '\0') {
 		(void)fputc(' ', stdout);
@@ -480,7 +465,6 @@ int main(int argc, char **argv)
 	    exit(EXIT_SUCCESS);
 	}
 
-	/*@-boolops@*/
 	/*
 	 * We used to wait on DEVICE_SET here.  That doesn't work
 	 * anymore because when the demon generates its response it
@@ -490,7 +474,7 @@ int main(int argc, char **argv)
 	 * sent and will shortly take effect.
 	 */
 	if (to_nmea) {
-	    if (!gps_query(&gpsdata, NON_ERROR, (int)timeout, 
+	    if (!gps_query(&gpsdata, NON_ERROR, (int)timeout,
 			   "?DEVICE={\"path\":\"%s\",\"native\":0}\r\n",
 			   device)) {
 		gpsd_log(&context.errout, LOG_ERROR,
@@ -514,7 +498,6 @@ int main(int argc, char **argv)
 			 "%s mode change succeeded\n",
 			 gpsdata.dev.path);
 	}
-	/*@+boolops@*/
 	if (speed != NULL) {
 	    char parity = 'N';
 	    char stopbits = '1';
@@ -525,7 +508,6 @@ int main(int argc, char **argv)
 				 device, speed);
 	    else {
 		char *modespec = strchr(speed, ':');
-		/*@ +charint @*/
 		status = 0;
 		if (modespec!=NULL) {
 		    *modespec = '\0';
@@ -587,7 +569,6 @@ int main(int argc, char **argv)
 		exit(EXIT_FAILURE);
 	    }
 
-	/*@ -mustfreeonly -immediatetrans @*/
 	gps_context_init(&context, "gpsctl");
 	context.errout.debug = debuglevel;
 	session.context = &context;
@@ -609,7 +590,6 @@ int main(int argc, char **argv)
 		session.device_type->mode_switcher(&session, MODE_NMEA);
 	gpsd_wrap(&session);
 	exit(EXIT_SUCCESS);
-	/*@ +mustfreeonly +immediatetrans @*/
 #endif /* RECONFIGURE_ENABLE */
     } else {
 	/* access to the daemon failed, use the low-level facilities */
@@ -618,12 +598,11 @@ int main(int argc, char **argv)
 	fd_set rfds;
 
 	/*
-	 * Unless the user explicitly requested it, always run to end of 
+	 * Unless the user explicitly requested it, always run to end of
 	 * hunt rather than timing out. Otherwise we can easily get messages
-	 * that spuriously look like failure at high baud rates. 
+	 * that spuriously look like failure at high baud rates.
 	 */
 
-	/*@ -mustfreeonly -immediatetrans @*/
 	gps_context_init(&context, "gpsctl");
 	context.errout.debug = debuglevel;
 	session.context = &context;	/* in case gps_init isn't called */
@@ -642,6 +621,8 @@ int main(int argc, char **argv)
 	 */
 	if (!(forcetype != NULL && echo)) {
 	    int maxfd = 0;
+	    int activated = -1;
+
 	    if (device == NULL) {
 		gpsd_log(&context.errout, LOG_ERROR,
 			 "device must be specified for low-level access.\n");
@@ -649,22 +630,27 @@ int main(int argc, char **argv)
 	    }
 
 	    gpsd_init(&session, &context, device);
-	    if (gpsd_activate(&session, O_PROBEONLY) < 0) {
+	    activated = gpsd_activate(&session, O_PROBEONLY);
+	    if ( 0 > activated ) {
+		if ( PLACEHOLDING_FD == activated ) {
+		    (void)printf("%s identified as a %s.\n",
+                       device, gpsd_id(&session));
+		    exit(EXIT_SUCCESS);
+	        }
 		gpsd_log(&context.errout, LOG_ERROR,
 			 "initial GPS device %s open failed\n",
 			 device);
 		exit(EXIT_FAILURE);
 	    }
-	    gpsd_log(&context.errout, LOG_INF, 
+	    gpsd_log(&context.errout, LOG_INF,
 		     "device %s activated\n", session.gpsdata.dev.path);
-	    /*@i1@*/FD_SET(session.gpsdata.gps_fd, &all_fds);
+	    FD_SET(session.gpsdata.gps_fd, &all_fds);
 	    if (session.gpsdata.gps_fd > maxfd)
 		 maxfd = session.gpsdata.gps_fd;
 
 	    /* initialize the GPS context's time fields */
 	    gpsd_time_init(&context, time(NULL));
 
-	    /*@-compdef@*/
 	    /* grab packets until we time out, get sync, or fail sync */
 	    for (hunting = true; hunting; )
 	    {
@@ -704,7 +690,6 @@ int main(int argc, char **argv)
 		    break;
 		}
 	    }
-	    /*@+compdef@*/
 
 	    gpsd_log(&context.errout, LOG_PROG,
 		     "%s looks like a %s at %d.\n",
@@ -738,7 +723,6 @@ int main(int argc, char **argv)
 	/* now perform the actual control function */
 	status = 0;
 #ifdef RECONFIGURE_ENABLE
-	/*@ -nullderef @*/
 	if (to_nmea || to_binary) {
 	    bool write_enable = context.readonly;
 	    context.readonly = false;
@@ -764,7 +748,6 @@ int main(int argc, char **argv)
 	    char *modespec;
 
 	    modespec = strchr(speed, ':');
-	    /*@ +charint @*/
 	    status = 0;
 	    if (modespec!=NULL) {
 		*modespec = '\0';
@@ -834,7 +817,6 @@ int main(int argc, char **argv)
 	}
 #endif /* RECONFIGURE_ENABLE */
 #ifdef CONTROLSEND_ENABLE
-	/*@ -compdef @*/
 	if (control) {
 	    bool write_enable = context.readonly;
 	    context.readonly = false;
@@ -855,14 +837,10 @@ int main(int argc, char **argv)
 	    }
 	    context.readonly = write_enable;
 	}
-	/*@ +compdef @*/
 #endif /* CONTROLSEND_ENABLE */
 
 	exit(status);
-	/*@ +nullderef @*/
-	/*@ +mustfreeonly +immediatetrans @*/
     }
 }
-/*@+mustfreeonly +observertrans +statictrans@*/
 
 /* end */
