@@ -16,18 +16,17 @@
 #include <stdlib.h>
 #include <stdbool.h>
 #include <stdarg.h>
-#include <ctype.h>
 #include <setjmp.h>
 #include <assert.h>
-#include <pwd.h>
-#include <grp.h>
 #include <math.h>
 #include <syslog.h>
 #include <errno.h>
-#include <fcntl.h>
 #include <signal.h>
+#include <ctype.h>
+#include <pwd.h>
+#include <grp.h>
+#include <fcntl.h>
 #include <pthread.h>
-#ifndef S_SPLINT_S
 #include <netdb.h>
 #ifndef AF_UNSPEC
 #include <sys/socket.h>
@@ -37,10 +36,7 @@
 #endif /* INADDR_ANY */
 #include <sys/un.h>
 #include <arpa/inet.h>     /* for htons() and friends */
-#endif /* S_SPLINT_S */
-#ifndef S_SPLINT_S
 #include <unistd.h>
-#endif /* S_SPLINT_S */
 
 #include "gpsd_config.h"
 
@@ -160,8 +156,6 @@ static int sd_socket_count = 0;
 #endif
 #endif
 
-#define UNALLOCATED_FD	-1
-
 static volatile sig_atomic_t signalled;
 
 static void onsig(int sig)
@@ -253,7 +247,6 @@ static socket_t filesock(char *filename)
     struct sockaddr_un addr;
     socket_t sock;
 
-    /*@ -mayaliasunique -usedef @*/
     if (BAD_SOCKET(sock = socket(AF_UNIX, SOCK_STREAM, 0))) {
 	gpsd_log(&context.errout, LOG_ERROR,
 		 "Can't create device-control socket\n");
@@ -273,7 +266,6 @@ static socket_t filesock(char *filename)
 	(void)close(sock);
 	return -1;
     }
-    /*@ +mayaliasunique +usedef @*/
 
     /* coverity[leaked_handle] This is an intentional allocation */
     return sock;
@@ -325,7 +317,7 @@ static socket_t passivesock_af(int af, char *service, char *tcp_or_udp, int qlen
      * qlen = maximum wait-queue length for connections
      */
     struct servent *pse;
-    struct protoent *ppe;	/* splint has a bug here */
+    struct protoent *ppe;
     sockaddr_t sat;
     int sin_len = 0;
     int type, proto, one = 1;
@@ -344,20 +336,18 @@ static socket_t passivesock_af(int af, char *service, char *tcp_or_udp, int qlen
     ppe = getprotobyname(tcp_or_udp);
     if (strcmp(tcp_or_udp, "udp") == 0) {
 	type = SOCK_DGRAM;
-	/*@i@*/ proto = (ppe) ? ppe->p_proto : IPPROTO_UDP;
+	proto = (ppe) ? ppe->p_proto : IPPROTO_UDP;
     } else {
 	type = SOCK_STREAM;
-	/*@i@*/ proto = (ppe) ? ppe->p_proto : IPPROTO_TCP;
+	proto = (ppe) ? ppe->p_proto : IPPROTO_TCP;
     }
 
-    /*@ -mustfreefresh +matchanyintegral @*/
     switch (af) {
     case AF_INET:
 	sin_len = sizeof(sat.sa_in);
 
 	memset((char *)&sat.sa_in, 0, sin_len);
 	sat.sa_in.sin_family = (sa_family_t) AF_INET;
-#ifndef S_SPLINT_S
 #ifndef FORCE_GLOBAL_ENABLE
 	if (!listen_global)
 	    sat.sa_in.sin_addr.s_addr = htonl(INADDR_LOOPBACK);
@@ -365,24 +355,20 @@ static socket_t passivesock_af(int af, char *service, char *tcp_or_udp, int qlen
 #endif /* FORCE_GLOBAL_ENABLE */
 	    sat.sa_in.sin_addr.s_addr = htonl(INADDR_ANY);
 	sat.sa_in.sin_port = htons(port);
-#endif /* S_SPLINT_S */
 
 	af_str = "IPv4";
 	/* see PF_INET6 case below */
 	s = socket(PF_INET, type, proto);
 	if (s > -1 ) {
-	/*@-unrecog@*/
 	/* Set packet priority */
 	if (setsockopt(s, IPPROTO_IP, IP_TOS, &dscp, sizeof(dscp)) == -1)
 	    gpsd_log(&context.errout, LOG_WARN,
 		     "Warning: SETSOCKOPT TOS failed\n");
 	}
-	/*@+unrecog@*/
 
 	break;
 #ifdef IPV6_ENABLE
     case AF_INET6:
-#ifndef S_SPLINT_S
 	sin_len = sizeof(sat.sa_in6);
 
 	memset((char *)&sat.sa_in6, 0, sin_len);
@@ -425,7 +411,6 @@ static socket_t passivesock_af(int af, char *service, char *tcp_or_udp, int qlen
 		gpsd_log(&context.errout, LOG_WARN,
 			 "Warning: SETSOCKOPT TOS failed\n");
 	}
-#endif /* S_SPLINT_S */
 	break;
 #endif  /* IPV6_ENABLE */
     default:
@@ -468,12 +453,11 @@ static socket_t passivesock_af(int af, char *service, char *tcp_or_udp, int qlen
 
     gpsd_log(&context.errout, LOG_SPIN, "passivesock_af() -> %d\n", s);
     return s;
-    /*@ +mustfreefresh -matchanyintegral @*/
 }
 
 /* *INDENT-OFF* */
 static int passivesocks(char *service, char *tcp_or_udp,
-			int qlen, /*@out@*/socket_t socks[])
+			int qlen, socket_t socks[])
 {
     int numsocks = AFCOUNT;
     int i;
@@ -528,7 +512,7 @@ static void unlock_subscriber(struct subscriber_t *sub)
     (void)pthread_mutex_unlock(&sub->mutex);
 }
 
-static /*@null@*//*@observer@ */ struct subscriber_t *allocate_client(void)
+static struct subscriber_t *allocate_client(void)
 /* return the address of a subscriber structure allocated for a new session */
 {
     int si;
@@ -576,7 +560,6 @@ static void detach_client(struct subscriber_t *sub)
     sub->policy.devpath[0] = '\0';
     sub->fd = UNALLOCATED_FD;
     unlock_subscriber(sub);
-    /*@+mustfreeonly@*/
 }
 
 static ssize_t throttled_write(struct subscriber_t *sub, char *buf,
@@ -590,6 +573,7 @@ static ssize_t throttled_write(struct subscriber_t *sub, char *buf,
 	    gpsd_log(&context.errout, LOG_CLIENT,
 		     "=> client(%d): %s\n", sub_index(sub), buf);
 	else {
+#ifndef __clang_analyzer__
 	    char *cp, buf2[MAX_PACKET_LENGTH * 3];
 	    buf2[0] = '\0';
 	    for (cp = buf; cp < buf + len; cp++)
@@ -597,6 +581,7 @@ static ssize_t throttled_write(struct subscriber_t *sub, char *buf,
 			       "%02x", (unsigned int)(*cp & 0xff));
 	    gpsd_log(&context.errout, LOG_CLIENT,
 		     "=> client(%d): =%s\n", sub_index(sub),	buf2);
+#endif /* __clang_analyzer__ */
 	}
     }
 
@@ -627,7 +612,7 @@ static ssize_t throttled_write(struct subscriber_t *sub, char *buf,
 		 "client(%d) timed out.\n", sub_index(sub));
     else
 	gpsd_log(&context.errout, LOG_INF,
-		 "client(%d) write: %s\n", 
+		 "client(%d) write: %s\n",
 		 sub_index(sub), strerror(errno));
     detach_client(sub);
     return status;
@@ -665,8 +650,6 @@ static void deactivate_device(struct gps_device_t *device)
     if (!BAD_SOCKET(device->gpsdata.gps_fd)) {
 	FD_CLR(device->gpsdata.gps_fd, &all_fds);
 	adjust_max_fd(device->gpsdata.gps_fd, false);
-#if defined(PPS_ENABLE) && defined(TIOCMIWAIT)
-#endif /* defined(PPS_ENABLE) && defined(TIOCMIWAIT) */
 #ifdef NTPSHM_ENABLE
 	ntpshm_link_deactivate(device);
 #endif /* NTPSHM_ENABLE */
@@ -676,7 +659,7 @@ static void deactivate_device(struct gps_device_t *device)
 
 #if defined(SOCKET_EXPORT_ENABLE) || defined(CONTROL_SOCKET_ENABLE)
 /* *INDENT-OFF* */
-/*@null@*//*@observer@*/ static struct gps_device_t *find_device(/*@null@*/const char
+static struct gps_device_t *find_device(const char
 								 *device_name)
 /* find the device block for an existing device name */
 {
@@ -693,9 +676,20 @@ static void deactivate_device(struct gps_device_t *device)
 /* *INDENT-ON* */
 #endif /* defined(SOCKET_EXPORT_ENABLE) || defined(CONTROL_SOCKET_ENABLE) */
 
-static bool open_device( /*@null@*/struct gps_device_t *device)
+static bool open_device( struct gps_device_t *device)
+/* open the input device
+ * return: false on failure
+ *         true on success
+ */
 {
-    if (NULL == device || gpsd_activate(device, O_OPTIMIZE) < 0) {
+    int activated = -1;
+
+    if (NULL == device ) {
+	return false;
+    }
+    activated = gpsd_activate(device, O_OPTIMIZE);
+    if ( ( 0 > activated ) && ( PLACEHOLDING_FD != activated ) ) {
+	/* failed to open device, and it is not a /dev/ppsX */
 	return false;
     }
 
@@ -706,13 +700,18 @@ static bool open_device( /*@null@*/struct gps_device_t *device)
      * 1PPS derived time data to ntpd/chrony.
      */
     ntpshm_link_activate(device);
-    gpsd_log(&context.errout, LOG_INF, 
-	     "NTPD ntpshm_link_activate: %d\n",
+    gpsd_log(&context.errout, LOG_INF,
+	     "PPS:%s ntpshm_link_activate: %d\n",
+	     device->gpsdata.dev.path,
 	     device->shm_clock != NULL);
 #endif /* NTPSHM_ENABLE */
 
-    gpsd_log(&context.errout, LOG_INF, 
+    gpsd_log(&context.errout, LOG_INF,
 	     "device %s activated\n", device->gpsdata.dev.path);
+    if ( PLACEHOLDING_FD == activated ) {
+	/* it is a /dev/ppsX, no need to select() it */
+        return true;
+    }
     FD_SET(device->gpsdata.gps_fd, &all_fds);
     adjust_max_fd(device->gpsdata.gps_fd, true);
     ++highwater;
@@ -720,7 +719,10 @@ static bool open_device( /*@null@*/struct gps_device_t *device)
 }
 
 bool gpsd_add_device(const char *device_name, bool flag_nowait)
-/* add a device to the pool; open it right away if in nowait mode */
+/* add a device to the pool; open it right away if in nowait mode
+ * return: false on failure
+ *         true on success
+ */
 {
     struct gps_device_t *devp;
     bool ret = false;
@@ -758,21 +760,19 @@ bool gpsd_add_device(const char *device_name, bool flag_nowait)
 }
 
 #ifdef CONTROL_SOCKET_ENABLE
-/*@ observer @*/ static char *snarfline(char *p, /*@out@*/ char **out)
+static char *snarfline(char *p, char **out)
 /* copy the rest of the command line, before CR-LF */
 {
     char *q;
     static char stash[BUFSIZ];
 
-    /*@ -temptrans -mayaliasunique @*/
-    for (q = p; isprint((unsigned char) *p) && !isspace((unsigned char) *p) && /*@i@*/ (p - q < (ssize_t) sizeof(stash) - 1);
+    for (q = p; isprint((unsigned char) *p) && !isspace((unsigned char) *p) && (p - q < (ssize_t) sizeof(stash) - 1);
 	 p++)
 	continue;
     (void)memcpy(stash, q, (size_t) (p - q));
     stash[p - q] = '\0';
     *out = stash;
     return p;
-    /*@ +temptrans +mayaliasunique @*/
 }
 
 static void handle_control(int sfd, char *buf)
@@ -787,7 +787,6 @@ static void handle_control(int sfd, char *buf)
       * gpsdctl.c.  Be careful about keeping them in sync, or
       * hotplugging will have mysterious failures.
       */
-    /*@ -sefparams @*/
     if (buf[0] == '-') {
 	/* remove device named after - */
 	(void)snarfline(buf + 1, &stash);
@@ -919,7 +918,6 @@ static void handle_control(int sfd, char *buf)
 	/* unknown command */
 	ignore_return(write(sfd, "ERROR\n", 6));
     }
-    /*@ +sefparams @*/
 }
 #endif /* CONTROL_SOCKET_ENABLE */
 
@@ -949,6 +947,11 @@ static bool awaken(struct gps_device_t *device)
 	    gpsd_log(&context.errout, LOG_ERROR,
 		     "%s: device activation failed.\n",
 		     device->gpsdata.dev.path);
+		    gpsd_log(&context.errout, LOG_ERROR,
+				"%s: activation failed, freeing device\n",
+				device->gpsdata.dev.path);
+		    /* FIXME: works around a crash bug, but prevents retries */
+		    free_device(device);
 	    return false;
 	} else {
 	    gpsd_log(&context.errout, LOG_RAW,
@@ -975,7 +978,7 @@ static bool privileged_user(struct gps_device_t *device)
     /*
      * Yes, zero subscribers is possible. For example, gpsctl talking
      * to the daemon connects but doesn't necessarily issue a ?WATCH
-     * before shipping a request, which means it isn't marked as a 
+     * before shipping a request, which means it isn't marked as a
      * subscriber.
      */
     return subcount <= 1;
@@ -989,18 +992,20 @@ static void set_serial(struct gps_device_t *device,
     char parity = device->gpsdata.dev.parity;
     int wordsize = 8;
 
+#ifndef __clang_analyzer__
     while (isspace((unsigned char) *modestring))
 	modestring++;
-    if (strchr("78", *modestring) != NULL) {
+    if (*modestring && strchr("78", *modestring) != NULL) {
 	wordsize = (int)(*modestring++ - '0');
-	if (strchr("NOE", *modestring) != NULL) {
+	if (*modestring && strchr("NOE", *modestring) != NULL) {
 	    parity = *modestring++;
 	    while (isspace((unsigned char) *modestring))
 		modestring++;
-	    if (strchr("12", *modestring) != NULL)
+	    if (*modestring && strchr("12", *modestring) != NULL)
 		stopbits = (unsigned int)(*modestring - '0');
 	}
     }
+#endif /* __clang_analyzer__ */
 
     gpsd_log(&context.errout, LOG_PROG,
 	     "set_serial(%s,%u,%s) %c%d\n",
@@ -1077,18 +1082,6 @@ static void handle_request(struct subscriber_t *sub,
     struct gps_device_t *devp;
     const char *end = NULL;
 
-    /*
-     * There's a splint limitation that parameters can be declared
-     * @out@ or @null@ but not, apparently, both.  This collides with
-     * the (admittedly tricky) way we use endptr. The workaround is to
-     * declare it @null@ and use -compdef around the JSON reader calls.
-     */
-    /*@-compdef@*/
-    /*
-     * See above...
-     */
-    /*@-nullderef -nullpass@*/
-
     if (buf[0] == '?')
 	++buf;
     if (str_starts_with(buf, "DEVICES;")) {
@@ -1101,9 +1094,7 @@ static void handle_request(struct subscriber_t *sub,
 	if (*buf == ';') {
 	    ++buf;
 	} else {
-	    /*@-nullstate@*/
 	    int status = json_watch_read(buf + 1, &sub->policy, &end);
-	    /*@+nullstate@*/
 #ifndef TIMING_ENABLE
 	    sub->policy.timing = false;
 #endif /* TIMING_ENABLE */
@@ -1169,10 +1160,8 @@ static void handle_request(struct subscriber_t *sub,
 	} else {
 #ifdef RECONFIGURE_ENABLE
 	    struct gps_device_t *device;
-	    /*@-nullstate@*/
 	    /* first, select a device to operate on */
 	    int status = json_device_read(buf + 1, &devconf, &end);
-	    /*@+nullstate@*/
 	    if (end == NULL)
 		buf += strlen(buf);
 	    else {
@@ -1181,7 +1170,6 @@ static void handle_request(struct subscriber_t *sub,
 		buf = end;
 	    }
 	    device = NULL;
-	    /*@-branchstate@*/
 	    if (status != 0) {
 		(void)snprintf(reply, replylen,
 			       "{\"class\":\"ERROR\",\"message\":\"Invalid DEVICE: \"%s\"}\r\n",
@@ -1271,7 +1259,6 @@ static void handle_request(struct subscriber_t *sub,
 			    device->gpsdata.dev.cycle = devconf.cycle;
 		}
 	    }
-	    /*@+branchstate@*/
 #else /* RECONFIGURE_ENABLE */
 	    str_appendf(reply, replylen,
 			   "{\"class\":\"ERROR\",\"message\":\"Device configuration support not compiled.\"}\r\n");
@@ -1355,8 +1342,6 @@ static void handle_request(struct subscriber_t *sub,
     }
   bailout:
     *after = buf;
-    /*@+nullderef +nullpass@*/
-    /*@+compdef@*/
 }
 
 static void raw_report(struct subscriber_t *sub, struct gps_device_t *device)
@@ -1412,7 +1397,7 @@ static void pseudonmea_report(struct subscriber_t *sub,
 
 	if ((changed & REPORT_IS) != 0) {
 	    nmea_tpv_dump(device, buf, sizeof(buf));
-	    gpsd_log(&context.errout, LOG_IO, 
+	    gpsd_log(&context.errout, LOG_IO,
 		     "<= GPS (binary tpv) %s: %s\n",
 		     device->gpsdata.dev.path, buf);
 	    (void)throttled_write(sub, buf, strlen(buf));
@@ -1528,33 +1513,44 @@ static void all_reports(struct gps_device_t *device, gps_mask_t changed)
      */
     if ((changed & TIME_SET) == 0) {
 	//gpsd_log(&context.errout, LOG_PROG, "NTP: No time this packet\n");
+    } else if ( 0 >= device->fixcnt ) {
+        /* many GPS spew random times until a valid GPS fix */
+	//gpsd_log(&context.errout, LOG_PROG, "NTP: no fix\n");
     } else if (isnan(device->newdata.time)) {
 	//gpsd_log(&context.errout, LOG_PROG, "NTP: bad new time\n");
-#if defined(PPS_ENABLE) && !defined(S_SPLINT_S)
-    } else if (device->newdata.time <= device->pps_thread.fixin.real.tv_sec) {
+#if defined(PPS_ENABLE)
+    } else if (device->newdata.time <= device->pps_thread.fix_in.real.tv_sec) {
 	//gpsd_log(&context.errout, LOG_PROG, "NTP: Not a new time\n");
 #endif /* PPS_ENABLE */
     } else if (!device->ship_to_ntpd) {
 	//gpsd_log(&context.errout, LOG_PROG, "NTP: No precision time report\n");
     } else {
 	struct timedelta_t td;
+#if defined(PPS_ENABLE)
+	struct gps_device_t *ppsonly;
+#endif /* PPS_ENABLE */
+
 	ntp_latch(device, &td);
+
+#if defined(PPS_ENABLE)
+	/* propagate this in-band-time to all PPS-only devices */
+	for (ppsonly = devices; ppsonly < devices + MAX_DEVICES; ppsonly++)
+	    if (ppsonly->sourcetype == source_pps)
+		pps_thread_fixin(&ppsonly->pps_thread, &td);
+#endif /* PPS_ENABLE */
+
 #ifdef NTPSHM_ENABLE
 	if (device->shm_clock != NULL) {
-	    /*@-compdef@*/
 	    (void)ntpshm_put(device, device->shm_clock, &td);
-	    /*@+compdef@*/
 	}
 #endif /* NTPSHM_ENABLE */
 
 #ifdef SOCKET_EXPORT_ENABLE
-	/*@-type@*//* splint is confused about struct timespec */
 	notify_watchers(device, false, true,
 			"{\"class\":\"TOFF\",\"device\":\"%s\",\"real_sec\":%ld, \"real_nsec\":%ld,\"clock_sec\":%ld,\"clock_nsec\":%ld}\r\n",
 			device->gpsdata.dev.path,
 			td.real.tv_sec, td.real.tv_nsec,
 			td.clock.tv_sec, td.clock.tv_nsec);
-	/*@+type@*/
 #endif /* SOCKET_EXPORT_ENABLE */
 
     }
@@ -1583,10 +1579,10 @@ static void all_reports(struct gps_device_t *device, gps_mask_t changed)
 		    netgnss_report(&context, device, dgnss);
 	}
 #endif /* NETFEED_ENABLE */
-#if defined(DBUS_EXPORT_ENABLE) && !defined(S_SPLINT_S)
+#if defined(DBUS_EXPORT_ENABLE)
 	if (device->gpsdata.fix.mode > MODE_NO_FIX)
 	    send_dbus_fix(device);
-#endif /* defined(DBUS_EXPORT_ENABLE) && !defined(S_SPLINT_S) */
+#endif /* defined(DBUS_EXPORT_ENABLE) */
     }
 
 #ifdef SHM_EXPORT_ENABLE
@@ -1598,7 +1594,6 @@ static void all_reports(struct gps_device_t *device, gps_mask_t changed)
 #ifdef SOCKET_EXPORT_ENABLE
     /* update all subscribers associated with this device */
     for (sub = subscribers; sub < subscribers + MAX_CLIENTS; sub++) {
-	/*@-nullderef@*/
 	if (sub == NULL || sub->active == 0 || !subscribed(sub, device))
 	    continue;
 
@@ -1653,7 +1648,6 @@ static void all_reports(struct gps_device_t *device, gps_mask_t changed)
 		}
 	    }
 	}
-	/*@+nullderef@*/
     } /* subscribers */
 #endif /* SOCKET_EXPORT_ENABLE */
 }
@@ -1684,14 +1678,27 @@ static void ship_pps_message(struct gps_device_t *session,
 				   struct timedelta_t *td)
 /* on PPS interrupt, ship a message to all clients */
 {
-    /*@-type@*//* splint is confused about struct timespec */
+    int precision = -20;
+
+    if ( source_usb == session->sourcetype) {
+        /* PPS over USB not so good */
+	precision = -10;
+    }
+
+    /* real_XXX - the time the GPS thinks it is at the PPS edge */
+    /* clock_XXX - the time the system clock thinks it is at the PPS edge */
     notify_watchers(session, true, true,
-		    "{\"class\":\"PPS\",\"device\":\"%s\",\"real_sec\":%ld, \"real_nsec\":%ld,\"clock_sec\":%ld,\"clock_nsec\":%ld}\r\n",
+		    "{\"class\":\"PPS\",\"device\":\"%s\",\"real_sec\":%ld, \"real_nsec\":%ld,\"clock_sec\":%ld,\"clock_nsec\":%ld,\"precision\":%d}\r\n",
 		    session->gpsdata.dev.path,
 		    td->real.tv_sec, td->real.tv_nsec,
-		    td->clock.tv_sec, td->clock.tv_nsec);
-    /*@+type@*/
-	return;
+		    td->clock.tv_sec, td->clock.tv_nsec,
+                    precision);
+
+    /*
+     * PPS receipt resets the device's timeout.  This keeps PPS-only
+     * devices, which never deliver in-band data, from timing out.
+     */
+    session->gpsdata.online = timestamp();
 }
 #endif
 
@@ -1729,7 +1736,6 @@ static void netgnss_autoconnect(struct gps_context_t *context,
 	sp->dist = DGPS_THRESHOLD;
 	sp->server[0] = '\0';
     }
-    /*@ -usedef @*/
     while (fgets(buf, (int)sizeof(buf), sfp)) {
 	char *cp = strchr(buf, '#');
 	if (cp != NULL)
@@ -1749,7 +1755,7 @@ static void netgnss_autoconnect(struct gps_context_t *context,
 		    && (tp == NULL || hold.dist > tp->dist))
 		    tp = sp;
 	    if (tp != NULL)
-		memcpy(tp, &hold, sizeof(struct dgps_server_t));
+		*tp = hold;
 	}
     }
     (void)fclose(sfp);
@@ -1760,7 +1766,6 @@ static void netgnss_autoconnect(struct gps_context_t *context,
 		 (int)(DGPS_THRESHOLD / 1000));
 	return;
     }
-    /*@ +usedef @*/
 
     /* sort them and try the closest first */
     qsort((void *)keep, SERVER_SAMPLE, sizeof(struct dgps_server_t), srvcmp);
@@ -1796,12 +1801,11 @@ static void gpsd_terminate(struct gps_context_t *context CONDITIONALLY_UNUSED)
 #endif /* PPS_ENABLE */
 }
 
-/*@ -mustfreefresh @*/
 int main(int argc, char *argv[])
 {
     /* some of these statics suppress -W warnings due to longjmp() */
 #ifdef SOCKET_EXPORT_ENABLE
-    static char *gpsd_service = NULL;	/* this static pacifies splint */
+    static char *gpsd_service = NULL;
     struct subscriber_t *sub;
 #endif /* SOCKET_EXPORT_ENABLE */
     fd_set rfds;
@@ -1957,14 +1961,12 @@ int main(int argc, char *argv[])
 
 
     /* might be time to daemonize */
-    /*@-unrecog@*/
     if (go_background) {
 	/* not SuS/POSIX portable, but we have our own fallback version */
 	if (daemon(0, 0) != 0)
 	    gpsd_log(&context.errout, LOG_ERROR,
 		     "demonization failed: %s\n",strerror(errno));
     }
-    /*@+unrecog@*/
 
     if (pid_file != NULL) {
 	FILE *fp;
@@ -1982,11 +1984,9 @@ int main(int argc, char *argv[])
     gpsd_log(&context.errout, LOG_INF, "launching (Version %s)\n", VERSION);
 
 #ifdef SOCKET_EXPORT_ENABLE
-    /*@ -observertrans @*/
     if (!gpsd_service)
 	gpsd_service =
 	    getservbyname("gpsd", "tcp") ? "gpsd" : DEFAULT_GPSD_PORT;
-    /*@ +observertrans @*/
     if (passivesocks(gpsd_service, "tcp", QLEN, msocks) < 1) {
 	gpsd_log(&context.errout, LOG_ERR,
 		 "command sockets creation failed, netlib errors %d, %d\n",
@@ -2004,18 +2004,18 @@ int main(int argc, char *argv[])
 	// nice() can ONLY succeed when run as root!
 	// do not even bother as non-root
 	if (nice(NICEVAL) == -1 && errno != 0)
-	    gpsd_log(&context.errout, LOG_INF,
-		     "NTPD o=priority setting failed.\n");
+	    gpsd_log(&context.errout, LOG_WARN,
+		     "PPS: o=priority setting failed. Time accuracty will be degraded\n");
     }
     /*
      * By initializing before we drop privileges, we guarantee that even
-     * hotplugged devices added *after* we drop privileges will be able 
+     * hotplugged devices added *after* we drop privileges will be able
      * to use segments 0 and 1.
      */
     (void)ntpshm_context_init(&context);
 #endif /* NTPSHM_ENABLE */
 
-#if defined(DBUS_EXPORT_ENABLE) && !defined(S_SPLINT_S)
+#if defined(DBUS_EXPORT_ENABLE)
     /* we need to connect to dbus as root */
     if (initialize_dbus_connection()) {
 	/* the connection could not be started */
@@ -2024,7 +2024,7 @@ int main(int argc, char *argv[])
     } else
 	gpsd_log(&context.errout, LOG_PROG,
 		 "successfully connected to the DBUS system bus\n");
-#endif /* defined(DBUS_EXPORT_ENABLE) && !defined(S_SPLINT_S) */
+#endif /* defined(DBUS_EXPORT_ENABLE) */
 
 #ifdef SHM_EXPORT_ENABLE
     /* create the shared segment as root so readers can't mess with it */
@@ -2063,13 +2063,10 @@ int main(int argc, char *argv[])
 	 * of any compromises in the code.  It requires that all GPS
 	 * devices have their group read/write permissions set.
 	 */
-	/*@-nullpass@*/
 	if (setgroups(0, NULL) != 0)
 	    gpsd_log(&context.errout, LOG_ERROR,
 		     "setgroups() failed, errno %s\n",
 		     strerror(errno));
-	/*@+nullpass@*/
-	/*@-type@*/
 #ifdef GPSD_GROUP
 	{
 	    struct group *grp = getgrnam(GPSD_GROUP);
@@ -2096,7 +2093,6 @@ int main(int argc, char *argv[])
 		gpsd_log(&context.errout, LOG_ERROR,
 			    "setuid() failed, errno %s\n",
 			    strerror(errno));
-	/*@+type@*/
     }
     gpsd_log(&context.errout, LOG_INF,
 	     "running with effective group ID %d\n", getegid());
@@ -2106,13 +2102,10 @@ int main(int argc, char *argv[])
 #ifdef SOCKET_EXPORT_ENABLE
     for (i = 0; i < NITEMS(subscribers); i++) {
 	subscribers[i].fd = UNALLOCATED_FD;
-#ifndef S_SPLINT_S
 	(void)pthread_mutex_init(&subscribers[i].mutex, NULL);
-#endif /* S_SPLINT_S */
     }
 #endif /* SOCKET_EXPORT_ENABLE*/
 
-    /*@-compdef -compdestroy@*/
     {
 	struct sigaction sa;
 
@@ -2133,7 +2126,6 @@ int main(int argc, char *argv[])
 	(void)sigaction(SIGQUIT, &sa, NULL);
 	(void)signal(SIGPIPE, SIG_IGN);
     }
-    /*@+compdef +compdestroy@*/
 
     /* daemon got termination or interrupt signal */
     if (setjmp(restartbuf) > 0) {
@@ -2193,10 +2185,8 @@ int main(int argc, char *argv[])
 	for (i = 0; i < AFCOUNT; i++) {
 	    if (msocks[i] >= 0 && FD_ISSET(msocks[i], &rfds)) {
 		socklen_t alen = (socklen_t) sizeof(fsin);
-		/*@+matchanyintegral@*/
 		socket_t ssock =
 		    accept(msocks[i], (struct sockaddr *)&fsin, &alen);
-		/*@+matchanyintegral@*/
 
 		if (BAD_SOCKET(ssock))
 		    gpsd_log(&context.errout, LOG_ERROR,
@@ -2248,9 +2238,7 @@ int main(int argc, char *argv[])
 	/* also be open to new control-socket connections */
 	if (csock > -1 && FD_ISSET(csock, &rfds)) {
 	    socklen_t alen = (socklen_t) sizeof(fsin);
-	    /*@+matchanyintegral@*/
 	    socket_t ssock = accept(csock, (struct sockaddr *)&fsin, &alen);
-	    /*@-matchanyintegral@*/
 
 	    if (BAD_SOCKET(ssock))
 		gpsd_log(&context.errout, LOG_ERROR,
@@ -2400,13 +2388,12 @@ int main(int argc, char *argv[])
 	    if (!device_needed && device->gpsdata.gps_fd > -1 &&
 		    device->lexer.type != BAD_PACKET) {
 		if (device->releasetime == 0) {
-		    device->releasetime = timestamp();
+		    device->releasetime = time(NULL);
 		    gpsd_log(&context.errout, LOG_PROG,
 			     "device %d (fd %d) released\n",
 			     (int)(device - devices),
 			     device->gpsdata.gps_fd);
-		} else if (timestamp() - device->releasetime >
-			RELEASE_TIMEOUT) {
+		} else if (time(NULL) - device->releasetime > RELEASE_TIMEOUT) {
 		    gpsd_log(&context.errout, LOG_PROG,
 			     "device %d closed\n",
 			     (int)(device - devices));
@@ -2419,8 +2406,8 @@ int main(int argc, char *argv[])
 
 	    if (device_needed && BAD_SOCKET(device->gpsdata.gps_fd) &&
 		    (device->opentime == 0 ||
-		    timestamp() - device->opentime > DEVICE_RECONNECT)) {
-		device->opentime = timestamp();
+		    time(NULL) - device->opentime > DEVICE_RECONNECT)) {
+		device->opentime = time(NULL);
 		gpsd_log(&context.errout, LOG_INF,
 			 "reconnection attempt on device %d\n",
 			 (int)(device - devices));
@@ -2496,4 +2483,3 @@ shutdown:
     return 0;
 }
 
-/*@ +mustfreefresh @*/
