@@ -13,7 +13,7 @@ struct exportmethod_t
 /* describe an export method */
 {
     const char *name;
-    /*@null@*/const char *magic;
+    const char *magic;
     const char *description;
 };
 
@@ -23,21 +23,21 @@ struct fixsource_t
     char *spec;		/* pointer to actual storage */
     char *server;
     char *port;
-    /*@null@*/char *device;
+    char *device;
 };
 
-/*@null observer@*/struct exportmethod_t *export_lookup(const char *);
-/*@null observer@*/struct exportmethod_t *export_default(void);
+struct exportmethod_t *export_lookup(const char *);
+struct exportmethod_t *export_default(void);
 void export_list(FILE *);
 enum unit {unspecified, imperial, nautical, metric};
 enum unit gpsd_units(void);
 enum deg_str_type { deg_dd, deg_ddmm, deg_ddmmss };
 float true2magnetic(double, double, double);
 
-extern /*@observer@*/ char *deg_to_str( enum deg_str_type type,  double f);
+extern char *deg_to_str( enum deg_str_type type,  double f);
 
-extern void gpsd_source_spec(/*@null@*/const char *fromstring,
-			     /*@out@*/struct fixsource_t *source);
+extern void gpsd_source_spec(const char *fromstring,
+			     struct fixsource_t *source);
 
 char *maidenhead(double n,double e);
 
