@@ -25,11 +25,9 @@
 #include <sys/select.h>
 #include <sys/stat.h>
 #include <assert.h>
-#ifndef S_SPLINT_S
 #include <sys/wait.h>
 #include <sys/socket.h>
 #include <unistd.h>
-#endif /* S_SPLINT_S */
 
 #include "gpsd.h"
 #include "matrix.h"
@@ -53,7 +51,7 @@ static void basic_report(const char *buf)
 
 void errout_reset(struct gpsd_errout_t *errout)
 {
-    errout->debug = 0;
+    errout->debug = LOG_SHOUT;
     errout->report = basic_report;
 }
 
@@ -63,15 +61,13 @@ static pthread_mutex_t report_mutex;
 void gpsd_acquire_reporting_lock(void)
 {
     int err;
-    /*@ -unrecog  (splint has no pthread declarations as yet) @*/
     err = pthread_mutex_lock(&report_mutex);
-    /*@ +unrecog @*/
     if ( 0 != err ) {
         /* POSIX says pthread_mutex_lock() should only fail if the
         thread holding the lock has died.  Best for gppsd to just die
         because things are FUBAR. */
 
-	(void) fprintf(stderr,"pthread_mutex_lock() failed: %s\n", 
+	(void) fprintf(stderr,"pthread_mutex_lock() failed: %s\n",
             strerror(errno));
 	exit(EXIT_FAILURE);
     }
@@ -80,16 +76,14 @@ void gpsd_acquire_reporting_lock(void)
 void gpsd_release_reporting_lock(void)
 {
     int err;
-    /*@ -unrecog (splint has no pthread declarations as yet) @*/
     err = pthread_mutex_unlock(&report_mutex);
-    /*@ +unrecog @*/
     if ( 0 != err ) {
         /* POSIX says pthread_mutex_unlock() should only fail when
         trying to unlock a lock that does not exist, or is not owned by
         this thread.  This should never happen, so best for gpsd to die
         because things are FUBAR. */
 
-	(void) fprintf(stderr,"pthread_mutex_unlock() failed: %s\n", 
+	(void) fprintf(stderr,"pthread_mutex_unlock() failed: %s\n",
             strerror(errno));
 	exit(EXIT_FAILURE);
     }
@@ -97,7 +91,7 @@ void gpsd_release_reporting_lock(void)
 #endif /* PPS_ENABLE */
 
 #ifndef SQUELCH_ENABLE
-static void visibilize(/*@out@*/char *outbuf, size_t outlen,
+static void visibilize(char *outbuf, size_t outlen,
 		       const char *inbuf, size_t inlen)
 {
     const char *sp;
@@ -114,7 +108,7 @@ static void visibilize(/*@out@*/char *outbuf, size_t outlen,
 #endif /* !SQUELCH_ENABLE */
 
 
-void gpsd_vlog(const struct gpsd_errout_t *errout, 
+void gpsd_vlog(const struct gpsd_errout_t *errout,
 			 const int errlevel,
 			 char *outbuf, size_t outlen,
 			 const char *fmt, va_list ap)
@@ -176,7 +170,7 @@ void gpsd_vlog(const struct gpsd_errout_t *errout,
 	visibilize(outbuf, outlen, buf, strlen(buf));
 
 	if (getpid() == getsid(getpid()))
-	    syslog((errlevel == 0) ? LOG_ERR : LOG_NOTICE, "%s", outbuf);
+	    syslog((errlevel <= LOG_SHOUT) ? LOG_ERR : LOG_NOTICE, "%s", outbuf);
 	else if (errout->report != NULL)
 	    errout->report(outbuf);
 	else
@@ -188,7 +182,7 @@ void gpsd_vlog(const struct gpsd_errout_t *errout,
 #endif /* !SQUELCH_ENABLE */
 }
 
-void gpsd_log(const struct gpsd_errout_t *errout, 
+void gpsd_log(const struct gpsd_errout_t *errout,
 		 const int errlevel,
 		 const char *fmt, ...)
 /* assemble msg in printf(3) style, use errout hook or syslog for delivery */
@@ -206,7 +200,7 @@ const char *gpsd_prettydump(struct gps_device_t *session)
 /* dump the current packet in a form optimised for eyeballs */
 {
     return gpsd_packetdump(session->msgbuf, sizeof(session->msgbuf),
-			   (char *)session->lexer.outbuffer, 
+			   (char *)session->lexer.outbuffer,
 			   session->lexer.outbuflen);
 }
 
@@ -248,10 +242,8 @@ static void gpsd_run_device_hook(struct gpsd_errout_t *errout,
     }
 }
 
-/*@-kepttrans@*/
 int gpsd_switch_driver(struct gps_device_t *session, char *type_name)
 {
-    /*@-mustfreeonly@*/
     const struct gps_type_t **dp;
     bool first_sync = (session->device_type != NULL);
     unsigned int i;
@@ -261,14 +253,13 @@ int gpsd_switch_driver(struct gps_device_t *session, char *type_name)
 
     gpsd_log(&session->context->errout, LOG_PROG,
 	     "switch_driver(%s) called...\n", type_name);
-    /*@ -compmempass @*/
     for (dp = gpsd_drivers, i = 0; *dp; dp++, i++)
 	if (strcmp((*dp)->type_name, type_name) == 0) {
 	    gpsd_log(&session->context->errout, LOG_PROG,
 		     "selecting %s driver...\n",
 		     (*dp)->type_name);
 	    gpsd_assert_sync(session);
-	    /*@i@*/ session->device_type = *dp;
+	    session->device_type = *dp;
 	    session->driver_index = i;
 #ifdef RECONFIGURE_ENABLE
 	    session->gpsdata.dev.mincycle = session->device_type->min_cycle;
@@ -286,14 +277,10 @@ int gpsd_switch_driver(struct gps_device_t *session, char *type_name)
     gpsd_log(&session->context->errout, LOG_ERROR,
 	     "invalid GPS type \"%s\".\n", type_name);
     return 0;
-    /*@ +compmempass @*/
-    /*@+mustfreeonly@*/
 }
-/*@+kepttrans@*/
 
-/*@-compdestroy -mustfreeonly -observertrans -dependenttrans@*/
-void gps_context_init(struct gps_context_t *context, 
-		      /*@observer@*/const char *label)
+void gps_context_init(struct gps_context_t *context,
+		      const char *label)
 {
     (void)memset(context, '\0', sizeof(struct gps_context_t));
     //context.readonly = false;
@@ -305,32 +292,24 @@ void gps_context_init(struct gps_context_t *context,
     errout_reset(&context->errout);
     context->errout.label = (char *)label;
 
-#if !defined(S_SPLINT_S) && defined(PPS_ENABLE)
-    /*@-nullpass@*/
+#if defined(PPS_ENABLE)
     (void)pthread_mutex_init(&report_mutex, NULL);
-    /*@+nullpass@*/
-#endif /* defined(S_SPLINT_S) defined(PPS_ENABLE) */
+#endif /* defined(PPS_ENABLE) */
 }
-/*@+compdestroy +mustfreeonly +observertrans +dependenttrans@*/
 
 void gpsd_init(struct gps_device_t *session, struct gps_context_t *context,
 	       const char *device)
 /* initialize GPS polling */
 {
-    /*@ -mayaliasunique @*/
     if (device != NULL)
 	(void)strlcpy(session->gpsdata.dev.path, device,
 		      sizeof(session->gpsdata.dev.path));
-    /*@ -mustfreeonly @*/
     session->device_type = NULL;	/* start by hunting packets */
     session->observed = 0;
     session->sourcetype = source_unknown;	/* gpsd_open() sets this */
     session->servicetype = service_unknown;	/* gpsd_open() sets this */
-    /*@ -temptrans @*/
     session->context = context;
-    /*@ +temptrans @*/
-    /*@ +mayaliasunique @*/
-    /*@ +mustfreeonly @*/
+    memset( session->subtype, 0, sizeof( session->subtype));
     gps_clear_fix(&session->gpsdata.fix);
     gps_clear_fix(&session->newdata);
     gps_clear_fix(&session->oldfix);
@@ -377,14 +356,12 @@ void gpsd_deactivate(struct gps_device_t *session)
 #endif /* of defined(NMEA2000_ENABLE) */
         (void)gpsd_close(session);
     if (session->mode == O_OPTIMIZE)
-	gpsd_run_device_hook(&session->context->errout, 
+	gpsd_run_device_hook(&session->context->errout,
 			     session->gpsdata.dev.path,
 			     "DEACTIVATE");
 #ifdef PPS_ENABLE
-    /*@-mustfreeonly@*/
     session->pps_thread.report_hook = NULL; /* tell any PPS-watcher thread to die */
 #endif /* PPS_ENABLE */
-    /*@-mustfreeonly@*/
     /* mark it inactivated */
     session->gpsdata.online = (timestamp_t)0;
 }
@@ -424,7 +401,6 @@ static void ppsthread_log(volatile struct pps_thread_t *pps_thread,
 #endif /* PPS_ENABLE */
 
 
-/*@-usereleased -compdef -compmempass@*/
 void gpsd_clear(struct gps_device_t *session)
 /* device has been opened - clear its storage for use */
 {
@@ -436,7 +412,7 @@ void gpsd_clear(struct gps_device_t *session)
     session->gpsdata.status = STATUS_NO_FIX;
     session->gpsdata.separation = NAN;
     session->mag_var = NAN;
-    session->releasetime = (timestamp_t)0;
+    session->releasetime = (time_t)0;
     session->badcount = 0;
 
     /* clear the private data union */
@@ -445,18 +421,21 @@ void gpsd_clear(struct gps_device_t *session)
     /* set up the context structure for the PPS thread monitor */
     memset((void *)&session->pps_thread, 0, sizeof(session->pps_thread));
     session->pps_thread.devicefd = session->gpsdata.gps_fd;
-    /*@i2@*/session->pps_thread.devicename = session->gpsdata.dev.path;
-    session->pps_thread.pps_hook = NULL;
+    session->pps_thread.devicename = session->gpsdata.dev.path;
     session->pps_thread.log_hook = ppsthread_log;
-    /*@i4@*/session->pps_thread.context = (void *)session;
+    session->pps_thread.context = (void *)session;
 #endif /* PPS_ENABLE */
 
-    session->opentime = timestamp();
+    session->opentime = time(NULL);
 }
-/*@+usereleased +compdef +compmempass@*/
 
 int gpsd_open(struct gps_device_t *session)
-/* open a device for access to its data */
+/* open a device for access to its data *
+ * return: the opened file descriptor
+ *         PLACEHOLDING_FD - for /dev/ppsX
+ *         UNALLOCATED_FD - for open failure
+ *         -1 - for open failure
+ */
 {
 #ifdef NETFEED_ENABLE
     /* special case: source may be a URI to a remote GNSS or DGPS service */
@@ -490,7 +469,7 @@ int gpsd_open(struct gps_device_t *session)
 		     netlib_errstr(dsock));
 	    return -1;
 	} else
-	    gpsd_log(&session->context->errout, LOG_SPIN, 
+	    gpsd_log(&session->context->errout, LOG_SPIN,
 		     "TCP device opened on fd %d\n", dsock);
 	session->gpsdata.gps_fd = dsock;
 	session->sourcetype = source_tcp;
@@ -526,7 +505,6 @@ int gpsd_open(struct gps_device_t *session)
 #endif /* NETFEED_ENABLE */
 #ifdef PASSTHROUGH_ENABLE
     if (str_starts_with(session->gpsdata.dev.path, "gpsd://")) {
-	/*@-branchstate -nullpass@*/
 	char server[strlen(session->gpsdata.dev.path)+1], *port;
 	socket_t dsock;
 	(void)strlcpy(server, session->gpsdata.dev.path + 7, sizeof(server));
@@ -546,23 +524,22 @@ int gpsd_open(struct gps_device_t *session)
 	} else
 	    gpsd_log(&session->context->errout, LOG_SPIN,
 		     "remote gpsd feed opened on fd %d\n", dsock);
-	/*@+branchstate +nullpass@*/
 	/* watch to remote is issued when WATCH is */
 	session->gpsdata.gps_fd = dsock;
 	session->sourcetype = source_gpsd;
 	return session->gpsdata.gps_fd;
     }
 #endif /* PASSTHROUGH_ENABLE */
-#if defined(NMEA2000_ENABLE) && !defined(S_SPLINT_S)
+#if defined(NMEA2000_ENABLE)
     if (str_starts_with(session->gpsdata.dev.path, "nmea2000://")) {
         return nmea2000_open(session);
     }
-#endif /* defined(NMEA2000_ENABLE) && !defined(S_SPLINT_S) */
+#endif /* defined(NMEA2000_ENABLE) */
     /* fall through to plain serial open */
+    /* could be a naked /dev/ppsX */
     return gpsd_serial_open(session);
 }
 
-/*@ -branchstate @*/
 int gpsd_activate(struct gps_device_t *session, const int mode)
 /* acquire a connection to the GPS device */
 {
@@ -574,60 +551,63 @@ int gpsd_activate(struct gps_device_t *session, const int mode)
 	session->mode = mode;
 
     // cppcheck-suppress pointerLessThanZero
-    if (session->gpsdata.gps_fd < 0)
-	return -1;
-    else {
-#ifdef NON_NMEA_ENABLE
-	/* if it's a sensor, it must be probed */
-        if ((session->servicetype == service_sensor) && 
-	    (session->sourcetype != source_can)) {
-	    const struct gps_type_t **dp;
-
-	    /*@ -mustfreeonly @*/
-	    for (dp = gpsd_drivers; *dp; dp++) {
-		if ((*dp)->probe_detect != NULL) {
-		    gpsd_log(&session->context->errout, LOG_PROG,
-			     "Probing \"%s\" driver...\n",
-			     (*dp)->type_name);
-		    /* toss stale data */
-		    (void)tcflush(session->gpsdata.gps_fd, TCIOFLUSH);
-		    if ((*dp)->probe_detect(session) != 0) {
-			gpsd_log(&session->context->errout, LOG_PROG,
-				 "Probe found \"%s\" driver...\n",
-				 (*dp)->type_name);
-			session->device_type = *dp;
-			gpsd_assert_sync(session);
-			goto foundit;
-		    } else
-			gpsd_log(&session->context->errout, LOG_PROG,
-				 "Probe not found \"%s\" driver...\n",
-				 (*dp)->type_name);
-		}
-	    }
-	    /*@ +mustfreeonly @*/
-	    gpsd_log(&session->context->errout, LOG_PROG,
-		     "no probe matched...\n");
-	}
-      foundit:
-#endif /* NON_NMEA_ENABLE */
-	gpsd_clear(session);
-	gpsd_log(&session->context->errout, LOG_INF,
-		 "gpsd_activate(%d): activated GPS (fd %d)\n",
-		 session->mode, session->gpsdata.gps_fd);
-	/*
-	 * We might know the device's type, but we shouldn't assume it has
-	 * retained its settings.  A revert hook might well have undone
-	 * them on the previous close.  Fire a reactivate event so drivers
-	 * can do something about this if they choose.
-	 */
-	if (session->device_type != NULL
-	    && session->device_type->event_hook != NULL)
-	    session->device_type->event_hook(session, event_reactivate);
+    if (session->gpsdata.gps_fd < 0) {
+        /* return could be -1, PLACEHOLDING_FD, of UNALLOCATED_FD */
+        if ( PLACEHOLDING_FD == session->gpsdata.gps_fd ) {
+            /* it is /dev/ppsX, need to set devicename, etc. */
+	    gpsd_clear(session);
+        }
+	return session->gpsdata.gps_fd;
     }
+
+#ifdef NON_NMEA_ENABLE
+    /* if it's a sensor, it must be probed */
+    if ((session->servicetype == service_sensor) &&
+	(session->sourcetype != source_can)) {
+	const struct gps_type_t **dp;
+
+	for (dp = gpsd_drivers; *dp; dp++) {
+	    if ((*dp)->probe_detect != NULL) {
+		gpsd_log(&session->context->errout, LOG_PROG,
+			 "Probing \"%s\" driver...\n",
+			 (*dp)->type_name);
+		/* toss stale data */
+		(void)tcflush(session->gpsdata.gps_fd, TCIOFLUSH);
+		if ((*dp)->probe_detect(session) != 0) {
+		    gpsd_log(&session->context->errout, LOG_PROG,
+			     "Probe found \"%s\" driver...\n",
+			     (*dp)->type_name);
+		    session->device_type = *dp;
+		    gpsd_assert_sync(session);
+		    goto foundit;
+		} else
+		    gpsd_log(&session->context->errout, LOG_PROG,
+			     "Probe not found \"%s\" driver...\n",
+			     (*dp)->type_name);
+	    }
+	}
+	gpsd_log(&session->context->errout, LOG_PROG,
+		 "no probe matched...\n");
+    }
+foundit:
+#endif /* NON_NMEA_ENABLE */
+
+    gpsd_clear(session);
+    gpsd_log(&session->context->errout, LOG_INF,
+	     "gpsd_activate(%d): activated GPS (fd %d)\n",
+	     session->mode, session->gpsdata.gps_fd);
+    /*
+     * We might know the device's type, but we shouldn't assume it has
+     * retained its settings.  A revert hook might well have undone
+     * them on the previous close.  Fire a reactivate event so drivers
+     * can do something about this if they choose.
+     */
+    if (session->device_type != NULL
+	&& session->device_type->event_hook != NULL)
+	session->device_type->event_hook(session, event_reactivate);
     return session->gpsdata.gps_fd;
 }
 
-/*@ +branchstate @*/
 
 #ifndef NOFLOATS_ENABLE
 /*****************************************************************************
@@ -720,7 +700,7 @@ driver.
 
 
 static gps_mask_t fill_dop(const struct gpsd_errout_t *errout,
-			   const struct gps_data_t * gpsdata, 
+			   const struct gps_data_t * gpsdata,
 			   struct dop_t * dop)
 {
     double prod[4][4];
@@ -827,7 +807,6 @@ static gps_mask_t fill_dop(const struct gpsd_errout_t *errout,
 	     dop->vdop, pdop, dop->pdop, tdop, dop->tdop, gdop, dop->gdop);
 #endif
 
-    /*@ -usedef @*/
     if (isnan(dop->xdop) != 0) {
 	dop->xdop = xdop;
     }
@@ -849,7 +828,6 @@ static gps_mask_t fill_dop(const struct gpsd_errout_t *errout,
     if (isnan(dop->gdop) != 0) {
 	dop->gdop = gdop;
     }
-    /*@ +usedef @*/
 
     return DOP_SET;
 }
@@ -921,9 +899,14 @@ static void gpsd_error_model(struct gps_device_t *session,
      * expected time error should be half the resolution of
      * the GPS clock, so we put the bound of the error
      * in as a constant pending getting it from each driver.
-     * FIXME: increase this if no leap-second has been seen
-     * and it's less than 750s (one almanac load cycle)
-     * from device powerup.
+     *
+     * In an ideal world, we'd increase this if no leap-second has
+     * been seen and it's less than 750s (one almanac load cycle) from
+     * device powerup. Alas, we have no way to know when device
+     * powerup occurred - depending on the receiver design it could be
+     * when the hardware was first powered up or when it was first
+     * opened.  Also, some devices (notably plain NMEA0183 receivers)
+     * never ship an indication of when they have valid leap second.
      */
     if (isnan(fix->time) == 0 && isnan(fix->ept) != 0)
 	fix->ept = 0.005;
@@ -953,7 +936,7 @@ static void gpsd_error_model(struct gps_device_t *session,
 	if (isnan(fix->eps) != 0) {
 	    if (oldfix->mode > MODE_NO_FIX && fix->mode > MODE_NO_FIX
 		&& isnan(oldfix->epx) == 0 && isnan(oldfix->epy) == 0
-		&& isnan(oldfix->time) == 0 && isnan(oldfix->time) == 0
+		&& isnan(oldfix->time) == 0 && isnan(fix->time) == 0
 		&& fix->time > oldfix->time) {
 		timestamp_t t = fix->time - oldfix->time;
 		double e =
@@ -1001,25 +984,22 @@ static void gpsd_error_model(struct gps_device_t *session,
     }
 
     /* save old fix for later error computations */
-    /*@ -mayaliasunique @*/
     if (fix->mode >= MODE_2D)
-	(void)memcpy(oldfix, fix, sizeof(struct gps_fix_t));
-    /*@ +mayaliasunique @*/
+	*oldfix = *fix;
 }
 #endif /* NOFLOATS_ENABLE */
 
-/*@ -mustdefine -compdef @*/
-int gpsd_await_data(/*@out@*/fd_set *rfds,
-		    /*@out@*/fd_set *efds,
+int gpsd_await_data(fd_set *rfds,
+		    fd_set *efds,
 		     const int maxfd,
-		     /*@in@*/fd_set *all_fds, 
+		     fd_set *all_fds,
 		     struct gpsd_errout_t *errout)
 /* await data from any socket in the all_fds set */
 {
     int status;
 
     FD_ZERO(efds);
-    (void)memcpy((char *)rfds, (char *)all_fds, sizeof(fd_set));
+    *rfds = *all_fds;
     gpsd_log(errout, LOG_RAW + 2, "select waits\n");
     /*
      * Poll for user commands or GPS data.  The timeout doesn't
@@ -1033,7 +1013,6 @@ int gpsd_await_data(/*@out@*/fd_set *rfds,
      * the once-per-second wakeup when no sensors are attached.
      * This cuts power consumption.
      */
-    /*@ -usedef -nullpass @*/
     errno = 0;
 
     status = pselect(maxfd + 1, rfds, NULL, NULL, NULL, NULL);
@@ -1057,7 +1036,6 @@ int gpsd_await_data(/*@out@*/fd_set *rfds,
 	    return AWAIT_FAILED;
 	}
     }
-    /*@ +usedef +nullpass @*/
 
     if (errout->debug >= LOG_SPIN) {
 	int i;
@@ -1078,7 +1056,6 @@ int gpsd_await_data(/*@out@*/fd_set *rfds,
 
     return AWAIT_GOT_INPUT;
 }
-/*@ +mustdefine +compdef @*/
 
 static bool hunt_failure(struct gps_device_t *session)
 /* after a bad packet, what should cue us to go to next autobaud setting? */
@@ -1106,7 +1083,7 @@ static bool hunt_failure(struct gps_device_t *session)
      * enough).  Removing this conjunct resurrected the failure
      * of test/daemon/tcp-torture.log.
      *
-     * Our third attempt, isatty(session->gpsdata.gps_fd) != 0 
+     * Our third attempt, isatty(session->gpsdata.gps_fd) != 0
      * && session->badcount++>1, reverts to the old test that worked
      * well on ttys for ttys and prevents non-tty devices from *ever*
      * having hunt failures. This has the cost that non-tty devices
@@ -1190,9 +1167,7 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
 #endif /* TIMING_ENABLE */
 
     if (session->lexer.type >= COMMENT_PACKET) {
-	/*@-shiftnegative@*/
 	session->observed |= PACKET_TYPEMASK(session->lexer.type);
-	/*@+shiftnegative@*/
     }
 
     /* can we get a full packet from the device? */
@@ -1254,7 +1229,7 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
 		 * Are we seeing a new packet type? Then we probably
 		 * want to change drivers.
 		 */
-		bool new_packet_type = 
+		bool new_packet_type =
 		    (newtype != session->device_type->packet_type);
 		/*
 		 * Possibly the old driver has a mode-switcher method, in
@@ -1277,7 +1252,6 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
 		 */
 		driver_change = new_packet_type && !dependent_nmea;
 	    }
-	    /*@-nullderef@*/
 	    if (driver_change) {
 		const struct gps_type_t **dp;
 
@@ -1290,7 +1264,6 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
 			break;
 		    }
 	    }
-	    /*@+nullderef@*/
 	    session->badcount = 0;
 	    session->gpsdata.dev.driver_mode = (session->lexer.type > NMEA_PACKET) ? MODE_BINARY : MODE_NMEA;
 	    /* FALL THROUGH */
@@ -1317,19 +1290,17 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
 		 session->gpsdata.dev.path);
 
 	/* track the packet count since achieving sync on the device */
-	if (driver_change 
+	if (driver_change
 		&& (session->drivers_identified & (1 << session->driver_index)) == 0) {
 	    speed_t speed = gpsd_get_speed(session);
 
-	    /*@-nullderef@*/
 	    /* coverity[var_deref_op] */
 	    gpsd_log(&session->context->errout, LOG_INF,
-		     "%s identified as type %s, %f sec @ %ubps\n",
+		     "%s identified as type %s, %ld sec @ %ubps\n",
 		     session->gpsdata.dev.path,
 		     session->device_type->type_name,
-		     timestamp() - session->opentime,
+		     (long)(time(NULL) - session->opentime),
 		     (unsigned int)speed);
-	    /*@+nullderef@*/
 
 	    /* fire the init_query method */
 	    if (session->device_type != NULL
@@ -1389,16 +1360,15 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
 	 * methods or an event hook had been active before that, we
 	 * keep the information about those capabilities.
 	 */
-	/*@-mustfreeonly@*/
 	if (!STICKY(session->device_type)
-	    && session->last_controller != NULL)
+	    && session->last_controller != NULL
+	    && STICKY(session->last_controller))
 	{
 	    session->device_type = session->last_controller;
 	    gpsd_log(&session->context->errout, LOG_PROG,
 		     "reverted to %s driver...\n",
 		     session->device_type->type_name);
 	}
-	/*@+mustfreeonly@*/
 #endif /* RECONFIGURE_ENABLE */
 
 #ifdef TIMING_ENABLE
@@ -1420,14 +1390,13 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
 	if ((received & SATELLITE_SET) != 0
 	    && session->gpsdata.satellites_visible > 0) {
 	    session->gpsdata.set |= fill_dop(&session->context->errout,
-					     &session->gpsdata, 
+					     &session->gpsdata,
 					     &session->gpsdata.dop);
 	    session->gpsdata.epe = NAN;
 	}
 #endif /* NOFLOATS_ENABLE */
 
 	/* copy/merge device data into staging buffers */
-	/*@-nullderef -nullpass@*/
 	if ((session->gpsdata.set & CLEAR_IS) != 0)
 	    gps_clear_fix(&session->gpsdata.fix);
 	/* don't downgrade mode if holding previous fix */
@@ -1438,11 +1407,9 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
 	gps_merge_fix(&session->gpsdata.fix,
 		      session->gpsdata.set, &session->newdata);
 #ifndef NOFLOATS_ENABLE
-	/*@i1@*/gpsd_error_model(session,
-				 &session->gpsdata.fix, &session->oldfix);
+	gpsd_error_model(session, &session->gpsdata.fix, &session->oldfix);
 #endif /* NOFLOATS_ENABLE */
 
-	/*@+nullderef -nullpass@*/
 
 	/*
 	 * Count good fixes. We used to check
@@ -1470,7 +1437,6 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
 	 * Sanity check.  This catches a surprising number of port and
 	 * driver errors, including 32-vs.-64-bit problems.
 	 */
-	/*@+relaxtypes +longunsignedintegral@*/
 	if ((session->gpsdata.set & TIME_SET) != 0) {
 	    if (session->newdata.time > time(NULL) + (60 * 60 * 24 * 365))
 		gpsd_log(&session->context->errout, LOG_WARN,
@@ -1479,7 +1445,6 @@ gps_mask_t gpsd_poll(struct gps_device_t *session)
 		gpsd_log(&session->context->errout, LOG_ERROR,
 			 "date is negative!\n");
 	}
-	/*@-relaxtypes -longunsignedintegral@*/
 
 	return session->gpsdata.set;
     }
@@ -1495,7 +1460,7 @@ int gpsd_multipoll(const bool data_ready,
     {
 	int fragments;
 
-	gpsd_log(&device->context->errout, LOG_RAW + 1, 
+	gpsd_log(&device->context->errout, LOG_RAW + 1,
 		 "polling %d\n", device->gpsdata.gps_fd);
 
 #ifdef NETFEED_ENABLE
@@ -1566,7 +1531,7 @@ int gpsd_multipoll(const bool data_ready,
 			gpsd_log(&device->context->errout, LOG_DATA,
 				 "%s will be repolled in %f seconds\n",
 				 device->gpsdata.dev.path, reawake_time);
-			device->reawake = timestamp() + reawake_time;
+			device->reawake = time(NULL) + reawake_time;
 			return DEVICE_UNREADY;
 		    }
 		}
@@ -1581,7 +1546,7 @@ int gpsd_multipoll(const bool data_ready,
 
 	    /* we got actual data, head off the reawake special case */
 	    device->zerokill = false;
-	    device->reawake = (timestamp_t)0;
+	    device->reawake = (time_t)0;
 
 	    /* must have a full packet to continue */
 	    if ((changed & PACKET_SET) == 0)
@@ -1604,7 +1569,7 @@ int gpsd_multipoll(const bool data_ready,
 
 	    /* handle data contained in this packet */
 	    if (device->lexer.type != BAD_PACKET)
-		/*@i1@*/handler(device, changed);
+		handler(device, changed);
 
 #ifdef __future__
 	    /*
@@ -1621,12 +1586,12 @@ int gpsd_multipoll(const bool data_ready,
 #endif /* __future__ */
 	}
     }
-    else if (device->reawake>0 && timestamp()>device->reawake) {
+    else if (device->reawake>0 && time(NULL) >device->reawake) {
 	/* device may have had a zero-length read */
 	gpsd_log(&device->context->errout, LOG_DATA,
 		 "%s reawakened after zero-length read\n",
 		 device->gpsdata.dev.path);
-	device->reawake = (timestamp_t)0;
+	device->reawake = (time_t)0;
 	device->zerokill = true;
 	return DEVICE_READY;
     }
@@ -1642,7 +1607,7 @@ void gpsd_wrap(struct gps_device_t *session)
 	gpsd_deactivate(session);
 }
 
-void gpsd_zero_satellites( /*@out@*/ struct gps_data_t *out)
+void gpsd_zero_satellites( struct gps_data_t *out)
 {
     (void)memset(out->skyview, '\0', sizeof(out->skyview));
     out->satellites_visible = 0;
@@ -1658,7 +1623,7 @@ void gpsd_zero_satellites( /*@out@*/ struct gps_data_t *out)
 }
 
 #ifdef NTP_ENABLE
-void ntp_latch(struct gps_device_t *device, struct timedelta_t /*@out@*/*td)
+void ntp_latch(struct gps_device_t *device, struct timedelta_t *td)
 /* latch the fact that we've saved a fix */
 {
     double fix_time, integral, fractional;
@@ -1683,16 +1648,12 @@ void ntp_latch(struct gps_device_t *device, struct timedelta_t /*@out@*/*td)
      * fix_time is in microSec
      * OK since GPS timestamps are millSec or worse */
     fractional = modf(fix_time, &integral);
-    /*@-type@*/ /* splint is confused about struct timespec */
     td->real.tv_sec = (time_t)integral;
     td->real.tv_nsec = (long)(fractional * 1e+9);
-    /*@+type@*/
 
 #ifdef PPS_ENABLE
     /* thread-safe update */
-    /*@-compdef@*/
     pps_thread_fixin(&device->pps_thread, td);
-    /*@+compdef@*/
 #endif /* PPS_ENABLE */
 }
 #endif /* NTP_ENABLE */
