@@ -14,7 +14,7 @@
 
 #define NTPD_BASE	0x4e545030	/* "NTP0" */
 
-/* 
+/*
  * How to read and write fields in an NTP shared segment.
  * This definition of shmTime is from ntpd source ntpd/refclock_shm.c
  *
@@ -25,7 +25,7 @@
  * 	-1 is about 100mSec jitter
  *	-10 is about 1 mSec jitter (GR-601W or other USB with 1ms poll interval)
  *	-13 is about 100 uSec
- *	-20 is about 1 nSec (typical for serial PPS)
+ *	-20 is about 1 uSec (typical for serial PPS)
  */
 
 struct shmTime
@@ -60,7 +60,9 @@ enum segstat_t {OK, NO_SEGMENT, NOT_READY, BAD_MODE, CLASH};
 
 struct shm_stat_t {
     enum segstat_t status;
-    struct timespec tvc, tvr, tvt;
+    struct timespec tvc;    /* System time when SHM read, for debug only */
+    struct timespec tvr;    /* System time at GPS time */
+    struct timespec tvt;    /* GPS time */
     int precision;
     int leap;
 };
@@ -75,11 +77,9 @@ struct timedelta_t {
 #define TIMEDELTA_DEFINED
 #endif /* TIMEDELTA_DEFINED */
 
-struct shmTime /*@null@*/ *shm_get(int, bool, bool);
+struct shmTime *shm_get(int, bool, bool);
 extern char *ntp_name(const int);
-enum segstat_t ntp_read(/*@null@*/struct shmTime *, 
-			 /*@out@*/struct shm_stat_t *,
-			 const bool);
+enum segstat_t ntp_read(struct shmTime *, struct shm_stat_t *, const bool);
 void ntp_write(volatile struct shmTime *, struct timedelta_t *, int, int);
 
 #endif /* GPSD_NTPSHM_H */
