@@ -8,9 +8,7 @@
 #include <stdlib.h>
 #include <getopt.h>
 #include <limits.h>
-#ifndef S_SPLINT_S
 #include <unistd.h>
-#endif /* S_SPLINT_S */
 
 #include "gpsd_config.h"
 #include "ntpshm.h"
@@ -18,6 +16,11 @@
 
 #define NTPSEGMENTS	256	/* NTPx for x any byte */
 
+/* difference between timespecs in nanoseconds */
+/* int is too small, avoid floats  */
+/* WARNING!  this will overflow if x and y differ by more than a few seconds */
+#define timespec_diff_ns(x, y)	(long)(((x).tv_sec-(y).tv_sec)*1000000000+(x).tv_nsec-(y).tv_nsec)
+
 static struct shmTime *segments[NTPSEGMENTS + 1];
 static struct timespec tick[NTPSEGMENTS + 1];
 
@@ -29,10 +32,14 @@ int main(int argc, char **argv)
     bool verbose = false;
     int nsamples = INT_MAX;
     time_t timeout = (time_t)INT_MAX, starttime = time(NULL);
+    double cycle = 1.0;
 
 #define USAGE	"usage: ntpshmmon [-s] [-n max] [-t timeout] [-v] [-h] [-V]\n"
-    while ((option = getopt(argc, argv, "hn:st:vV")) != -1) {
+    while ((option = getopt(argc, argv, "c:hn:st:vV")) != -1) {
 	switch (option) {
+	case 'c':
+	    cycle = atof(optarg);
+	    break;
 	case 'n':
 	    nsamples = atoi(optarg);
 	    break;
@@ -73,6 +80,7 @@ int main(int argc, char **argv)
     }
 
     (void)printf("ntpshmmon version 1\n");
+    (void)printf("#      Name   Seen@                Clock                Real               L Prec\n");
 
     do {
 	struct shm_stat_t	shm_stat;
@@ -84,20 +92,16 @@ int main(int argc, char **argv)
 	    switch(status)
 	    {
 	    case OK:
-		/*@-mustfreefresh -formattype@*/
-		/*@-type@*//* splint is confused about struct timespec */
-		if (shm_stat.tvc.tv_sec != tick[i].tv_sec || shm_stat.tvc.tv_nsec != tick[i].tv_nsec) {
+		if (timespec_diff_ns(shm_stat.tvc, tick[i]) >= cycle * 1000000000) {
 		    printf("sample %s %ld.%09ld %ld.%09ld %ld.%09ld %d %3d\n",
 			   ntp_name(i),
-			   shm_stat.tvc.tv_sec, shm_stat.tvc.tv_nsec,
-			   shm_stat.tvr.tv_sec, shm_stat.tvr.tv_nsec,
-			   shm_stat.tvt.tv_sec, shm_stat.tvt.tv_nsec,
+			   (long)shm_stat.tvc.tv_sec, shm_stat.tvc.tv_nsec,
+			   (long)shm_stat.tvr.tv_sec, shm_stat.tvr.tv_nsec,
+			   (long)shm_stat.tvt.tv_sec, shm_stat.tvt.tv_nsec,
 			   shm_stat.leap, shm_stat.precision);
 		    tick[i] = shm_stat.tvc;
 		    --nsamples;
 		}
-		/*@+type@*/
-		/*@+mustfreefresh +formattype@*/
 		break;
 	    case NO_SEGMENT:
 		break;
@@ -105,31 +109,27 @@ int main(int argc, char **argv)
 		/* do nothing, data not ready, wait another cycle */
 		break;
 	    case BAD_MODE:
-		/*@-mustfreefresh@*/
 		fprintf(stderr, "ntpshmmon: unknown mode %d on segment %s\n",
 			shm_stat.status, ntp_name(i));
-		/*@+mustfreefresh@*/
 		break;
 	    case CLASH:
 		/* do nothing, data is corrupt, wait another cycle */
 		break;
 	    default:
-		/*@-mustfreefresh@*/
 		fprintf(stderr, "ntpshmmon: unknown status %d on segment %s\n",
 			status, ntp_name(i));
-		/*@+mustfreefresh@*/
 		break;
 	    }
 	}
- 
+
 	/*
 	 * Even on a 1 Hz PPS, a sleep(1) may end up
          * being sleep(1.1) and missing a beat.  Since
 	 * we're ignoring duplicates via timestamp, polling
 	 * at interval < 1 sec shouldn't be a problem.
 	 */
-	(void)usleep(1000);
-    } while 
+	(void)usleep((useconds_t)(cycle * 1000));
+    } while
 	    (nsamples != 0 && time(NULL) - starttime < timeout);
 
     exit(EXIT_SUCCESS);
