@@ -15,17 +15,14 @@
 #include <assert.h>
 #include <stdio.h>
 #include <stdint.h>
-#ifndef S_SPLINT_S
 #include <unistd.h>
-#endif /* S_SPLINT_S*/
 
 #include "ntpshm.h"
 #include "compiler.h"
 
-struct shmTime /*@null@*/ *shm_get(const int unit, const bool create, const bool forall)
+struct shmTime *shm_get(const int unit, const bool create, const bool forall)
 /* initialize a SHM segment */
 {
-    /*@-mustfreefresh@*/
     struct shmTime *p = NULL;
     int shmid;
 
@@ -43,22 +40,19 @@ struct shmTime /*@null@*/ *shm_get(const int unit, const bool create, const bool
 	return NULL;
     }
     return p;
-    /*@+mustfreefresh@*/
 }
 
-/*@-statictrans@*/
 char *ntp_name(const int unit)
 /* return the name of a specified segment */
 {
     static char name[5] = "NTP\0";
 
-    /*@i2@*/name[3] = '0' + (char)unit;
+    name[3] = (char)('0' + unit);
 
     return name;
 }
-/*@+statictrans@*/
 
-enum segstat_t ntp_read(/*@null@*/struct shmTime *shm_in, /*@out@*/struct shm_stat_t *shm_stat, const bool consume)
+enum segstat_t ntp_read(struct shmTime *shm_in, struct shm_stat_t *shm_stat, const bool consume)
 /* try to grab a sample from the specified SHM segment */
 {
     volatile struct shmTime shmcopy, *shm = shm_in;
@@ -71,7 +65,6 @@ enum segstat_t ntp_read(/*@null@*/struct shmTime *shm_in, /*@out@*/struct shm_st
 	return NO_SEGMENT;
     }
 
-    /*@-type@*//* splint is confused about struct timespec */
     shm_stat->tvc.tv_sec = shm_stat->tvc.tv_nsec = 0;
 
     clock_gettime(CLOCK_REALTIME, &shm_stat->tvc);
@@ -103,9 +96,9 @@ enum segstat_t ntp_read(/*@null@*/struct shmTime *shm_in, /*@out@*/struct shm_st
 	shm->valid = 0;
     memory_barrier();
 
-    /* 
+    /*
      * Clash detection in case neither (a) nor (b) was true.
-     * Not supported in mode 0, and word access to the count field 
+     * Not supported in mode 0, and word access to the count field
      * must be atomic for this to work.
      */
     if (shmcopy.mode > 0 && cnt != shm->count) {
@@ -172,7 +165,6 @@ enum segstat_t ntp_read(/*@null@*/struct shmTime *shm_in, /*@out@*/struct shm_st
 	shm_stat->status = BAD_MODE;
 	break;
     }
-    /*@-type@*/
 
     /*
      * leap field is not a leap offset but a leap notification code.
