@@ -33,11 +33,9 @@ PERMISSIONS
 #include <ctype.h>
 #include <string.h>
 #include <errno.h>
-#ifndef S_SPLINT_S
 #include <netinet/in.h>
 #include <arpa/inet.h>		/* for htons() */
 #include <unistd.h>
-#endif /* S_SPLINT_S */
 
 #include "bits.h"
 #include "gpsd.h"
@@ -108,7 +106,7 @@ PERMISSIONS
  *      $P  -- Vendor-specific sentence
  *
  *      !AB -- NMEA 4.0 Base AIS station
- *      !AD -- MMEA 4.0 Dependent AIS Base Station 
+ *      !AD -- MMEA 4.0 Dependent AIS Base Station
  *      !AI -- Mobile AIS station
  *      !AN -- NMEA 4.0 Aid to Navigation AIS station
  *      !AR -- NMEA 4.0 AIS Receiving Station
@@ -194,9 +192,7 @@ static size_t oncore_payload_cksum_length(unsigned char id1, unsigned char id2)
 static bool character_pushback(struct gps_lexer_t *lexer, unsigned int newstate)
 /* push back the last character grabbed, setting a specified state */
 {
-    /*@-modobserver@*//* looks like a splint bug */
     --lexer->inbufptr;
-    /*@+modobserver@*/
     --lexer->char_counter;
     lexer->state = newstate;
     if (lexer->errout.debug >= LOG_RAW + 2)
@@ -221,7 +217,6 @@ static bool nextstate(struct gps_lexer_t *lexer, unsigned char c)
 #ifdef SUPERSTAR2_ENABLE
     static unsigned char ctmp;
 #endif /* SUPERSTAR2_ENABLE */
-/*@ +charint -casebreak @*/
     n++;
     switch (lexer->state) {
     case GROUND_STATE:
@@ -1427,7 +1422,6 @@ static bool nextstate(struct gps_lexer_t *lexer, unsigned char c)
 	break;
 #endif /* PASSTHROUGH_ENABLE */
     }
-/*@ -charint +casebreak @*/
 
     return true;	/* no pushback */
 }
@@ -1495,7 +1489,7 @@ static void character_discard(struct gps_lexer_t *lexer)
 
 /* entry points begin here */
 
-void lexer_init( /*@out@*/ struct gps_lexer_t *lexer)
+void lexer_init(struct gps_lexer_t *lexer)
 {
     lexer->char_counter = 0;
     lexer->retry_counter = 0;
@@ -1514,9 +1508,7 @@ void packet_parse(struct gps_lexer_t *lexer)
 {
     lexer->outbuflen = 0;
     while (packet_buffered_input(lexer) > 0) {
-	/*@ -modobserver @*/
 	unsigned char c = *lexer->inbufptr++;
-	/*@ +modobserver @*/
 	unsigned int oldstate = lexer->state;
 	if (!nextstate(lexer, c))
 	    continue;
@@ -1581,6 +1573,18 @@ void packet_parse(struct gps_lexer_t *lexer)
 		packet_accept(lexer, AIVDM_PACKET);
 	    else if (str_starts_with((char *)lexer->inbuffer, "!BSVDO"))
 		packet_accept(lexer, AIVDM_PACKET);
+	    else if (str_starts_with((char *)lexer->inbuffer, "!ABVDM"))
+		packet_accept(lexer, AIVDM_PACKET);
+	    else if (str_starts_with((char *)lexer->inbuffer, "!ABVDO"))
+		packet_accept(lexer, AIVDM_PACKET);
+	    else if (str_starts_with((char *)lexer->inbuffer, "!ANVDM"))
+		packet_accept(lexer, AIVDM_PACKET);
+	    else if (str_starts_with((char *)lexer->inbuffer, "!ANVDO"))
+		packet_accept(lexer, AIVDM_PACKET);
+	    else if (str_starts_with((char *)lexer->inbuffer, "!SAVDM"))
+		packet_accept(lexer, AIVDM_PACKET);
+	    else if (str_starts_with((char *)lexer->inbuffer, "!SAVDO"))
+		packet_accept(lexer, AIVDM_PACKET);
 	    else
 #endif /* AIVDM_ENABLE */
 		packet_accept(lexer, NMEA_PACKET);
@@ -1685,7 +1689,6 @@ void packet_parse(struct gps_lexer_t *lexer)
 		size_t n;
 		unsigned int ch, chksum;
 		n = 0;
-		/*@ +charint */
 #ifdef TSIP_ENABLE
 		/* shortcut garmin */
 		if (TSIP_PACKET == lexer->type)
@@ -1719,7 +1722,6 @@ void packet_parse(struct gps_lexer_t *lexer)
 		/* we used to say n++ here, but scan-build complains */
 		if (lexer->inbuffer[n] != ETX)
 		    goto not_garmin;
-		/*@ +charint */
 		chksum &= 0xff;
 		if (chksum) {
 		    gpsd_log(&lexer->errout, LOG_IO,
@@ -1750,7 +1752,7 @@ void packet_parse(struct gps_lexer_t *lexer)
 		 * 0x4c, Operating Parameters Report, data length 17
 		 * 0x54, One Satellite Bias, data length 4
 		 * 0x56, Velocity Fix (ENU), data length 20
-		 * 0x57, Last Computed Fix Report, data length 8 
+		 * 0x57, Last Computed Fix Report, data length 8
 		 * 0x5a, Raw Measurements
 		 * 0x5b, Satellite Ephemeris Status, data length 16
 		 * 0x5c, Satellite Tracking Status, data length 24
@@ -1764,20 +1766,19 @@ void packet_parse(struct gps_lexer_t *lexer)
 		 *
 		 * <DLE>[pkt id] [data] <DLE><ETX>
 		 *
-		 * The best description is in [TSIP], the Trimble Standard 
+		 * The best description is in [TSIP], the Trimble Standard
 		 * Interface Protocol manual; unless otherwise specified
-		 * that is where these type/length notifications are from. 
+		 * that is where these type/length notifications are from.
 		 *
 		 * Note that not all Trimble chips conform perfectly to this
 		 * specification, nor does it cover every packet type we
 		 * may see on the wire.
 		 */
-		/*@ +charint @*/
 		pkt_id = lexer->inbuffer[1];	/* packet ID */
                 /* *INDENT-OFF* */
-		if (!((0x13 == pkt_id) || 
-		      (0x1c == pkt_id) || 
-		      (0xbb == pkt_id) || 
+		if (!((0x13 == pkt_id) ||
+		      (0x1c == pkt_id) ||
+		      (0xbb == pkt_id) ||
 		      (0xbc == pkt_id) ||
 		      (0x38 == pkt_id))
 		    && ((0x41 > pkt_id) || (0x8f < pkt_id))) {
@@ -1787,7 +1788,6 @@ void packet_parse(struct gps_lexer_t *lexer)
 		    goto not_tsip;
 		}
                 /* *INDENT-ON* */
-		/*@ -ifempty */
 #define TSIP_ID_AND_LENGTH(id, len)	((id == pkt_id) && (len == packetlen-4))
 		if ((0x13 == pkt_id) && (1 <= packetlen))
 		    /* pass */ ;
@@ -1875,7 +1875,6 @@ void packet_parse(struct gps_lexer_t *lexer)
 		gpsd_log(&lexer->errout, LOG_RAW,
 			 "TSIP pkt_id = %#02x, packetlen= %zu\n",
 			 pkt_id, packetlen);
-		/*@ -charint +ifempty @*/
 		packet_accept(lexer, TSIP_PACKET);
 		packet_discard(lexer);
 		break;
@@ -1969,7 +1968,6 @@ void packet_parse(struct gps_lexer_t *lexer)
 	else if (lexer->state == EVERMORE_RECOGNIZED) {
 	    unsigned int n, crc, checksum, len;
 	    n = 0;
-	    /*@ +charint */
 	    if (lexer->inbuffer[n++] != DLE)
 		goto not_evermore;
 	    if (lexer->inbuffer[n++] != STX)
@@ -2005,7 +2003,6 @@ void packet_parse(struct gps_lexer_t *lexer)
 			 crc, checksum);
 		goto not_evermore;
 	    }
-	    /*@ +charint */
 	    packet_accept(lexer, EVERMORE_PACKET);
 	    packet_discard(lexer);
 	    break;
@@ -2027,7 +2024,6 @@ void packet_parse(struct gps_lexer_t *lexer)
 	    /* number of words */
 	    len = (uint16_t) (lexer->inbuffer[6] & 0xff);
 
-	    /*@ -type @*/
 	    /* expected checksum */
 	    xsum = getiw(7 + 2 * len);
 
@@ -2038,7 +2034,6 @@ void packet_parse(struct gps_lexer_t *lexer)
 		volatile uint32_t tmpdw  = (csum + 1) * (tmpw + n);
 		csum ^= (tmpdw & 0xffff) ^ ((tmpdw >> 16) & 0xffff);
 	    }
-	    /*@ +type @*/
 	    if (len == 0 || csum == xsum)
 		packet_accept(lexer, ITALK_PACKET);
 	    else {
@@ -2136,11 +2131,9 @@ ssize_t packet_get(int fd, struct gps_lexer_t *lexer)
 {
     ssize_t recvd;
 
-    /*@ -modobserver @*/
     errno = 0;
     recvd = read(fd, lexer->inbuffer + lexer->inbuflen,
 		 sizeof(lexer->inbuffer) - (lexer->inbuflen));
-    /*@ +modobserver @*/
     if (recvd == -1) {
 	if ((errno == EAGAIN) || (errno == EINTR)) {
 	    gpsd_log(&lexer->errout, LOG_RAW + 2, "no bytes ready\n");
@@ -2214,7 +2207,7 @@ ssize_t packet_get(int fd, struct gps_lexer_t *lexer)
 	return recvd;
 }
 
-void packet_reset( /*@out@*/ struct gps_lexer_t *lexer)
+void packet_reset(struct gps_lexer_t *lexer)
 /* return the packet machine to the ground state */
 {
     lexer->type = BAD_PACKET;
