@@ -30,28 +30,25 @@ PERMISSIONS
 #include "gpsd.h"
 #include "libgps.h" /* for SHM_PSEUDO_FD */
 
-/*@ -mustfreeonly -nullstate -mayaliasunique @*/
 
 bool shm_acquire(struct gps_context_t *context)
 /* initialize the shared-memory segment to be used for export */
 {
-    /*@-nullpass@*/
     long shmkey = getenv("GPSD_SHM_KEY") ? strtol(getenv("GPSD_SHM_KEY"), NULL, 0) : GPSD_SHM_KEY;
-    /*@+nullpass@*/
 
-    int shmid = shmget((key_t)shmkey, sizeof(struct gps_data_t), (int)(IPC_CREAT|0666));
+    int shmid = shmget((key_t)shmkey, sizeof(struct shmexport_t), (int)(IPC_CREAT|0666));
     if (shmid == -1) {
 	gpsd_log(&context->errout, LOG_ERROR,
 		 "shmget(0x%lx, %zd, 0666) for SHM export failed: %s\n",
 		 shmkey,
-		 sizeof(struct gps_data_t),
+		 sizeof(struct shmexport_t),
 		 strerror(errno));
 	return false;
     } else
 	gpsd_log(&context->errout, LOG_PROG,
 		 "shmget(0x%lx, %zd, 0666) for SHM export succeeded\n",
 		 shmkey,
-		 sizeof(struct gps_data_t));
+		 sizeof(struct shmexport_t));
 
     context->shmexport = (void *)shmat(shmid, 0, 0);
     if ((int)(long)context->shmexport == -1) {
@@ -93,9 +90,7 @@ void shm_update(struct gps_context_t *context, struct gps_data_t *gpsdata)
 	 */
 	shared->bookend2 = tick;
 	memory_barrier();
-	memcpy((void *)((char *)context->shmexport + offsetof(struct shmexport_t, gpsdata)),
-	       (void *)gpsdata,
-	       sizeof(struct gps_data_t));
+	shared->gpsdata = *gpsdata;
 	memory_barrier();
 #ifndef USE_QT
 	shared->gpsdata.gps_fd = SHM_PSEUDO_FD;
@@ -107,7 +102,6 @@ void shm_update(struct gps_context_t *context, struct gps_data_t *gpsdata)
     }
 }
 
-/*@ +mustfreeonly +nullstate +mayaliasunique @*/
 
 #endif /* SHM_EXPORT_ENABLE */
 
