@@ -19,9 +19,9 @@
 #include <errno.h>
 #include <ctype.h>
 
-#include "timespec_str.h"
+#include "timespec.h"
 
-/* Convert a normalized timespec to a nice string 
+/* Convert a normalized timespec to a nice string
  * put in it *buf, buf should be at least 22 bytes
  *
  * the returned buffer will look like, shortest case:
@@ -32,15 +32,14 @@
  *
  * So 12 chars, like this: "-0.123456789"
  *
- * Absolute worst case is 10 digits of seconds.  
+ * Absolute worst case is 10 digits of seconds.
  * So 21 digits like this: "-2147483647.123456789"
  *
 */
-void timespec_str(const struct timespec *ts, /*@out@*/char *buf, size_t buf_size)
+void timespec_str(const struct timespec *ts, char *buf, size_t buf_size)
 {
     char sign = ' ';
 
-    /*@-type@*//* splint is confused about timespec*/
     if ( (0 > ts->tv_nsec ) || ( 0 > ts->tv_sec ) ) {
 	sign = '-';
     }
@@ -48,7 +47,6 @@ void timespec_str(const struct timespec *ts, /*@out@*/char *buf, size_t buf_size
 			  sign,
 			  (long)labs(ts->tv_sec),
 			  (long)labs(ts->tv_nsec));
-    /*@+type@*/
 }
 
 /* end */
